

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.FileChooserDialog
    ( 

-- * Exported types
    FileChooserDialog(..)                   ,
    FileChooserDialogK                      ,
    toFileChooserDialog                     ,
    noFileChooserDialog                     ,


    ) where

import Data.GI.Base.ShortPrelude

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject

newtype FileChooserDialog = FileChooserDialog (ForeignPtr FileChooserDialog)
foreign import ccall "gtk_file_chooser_dialog_get_type"
    c_gtk_file_chooser_dialog_get_type :: IO GType

type instance ParentTypes FileChooserDialog = FileChooserDialogParentTypes
type FileChooserDialogParentTypes = '[Dialog, Window, Bin, Container, Widget, GObject.Object, Atk.ImplementorIface, Buildable, FileChooser]

instance GObject FileChooserDialog where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_file_chooser_dialog_get_type
    

class GObject o => FileChooserDialogK o
instance (GObject o, IsDescendantOf FileChooserDialog o) => FileChooserDialogK o

toFileChooserDialog :: FileChooserDialogK o => o -> IO FileChooserDialog
toFileChooserDialog = unsafeCastTo FileChooserDialog

noFileChooserDialog :: Maybe FileChooserDialog
noFileChooserDialog = Nothing

type family ResolveFileChooserDialogMethod (t :: Symbol) (o :: *) :: * where
    ResolveFileChooserDialogMethod "activate" o = WidgetActivateMethodInfo
    ResolveFileChooserDialogMethod "activateDefault" o = WindowActivateDefaultMethodInfo
    ResolveFileChooserDialogMethod "activateFocus" o = WindowActivateFocusMethodInfo
    ResolveFileChooserDialogMethod "activateKey" o = WindowActivateKeyMethodInfo
    ResolveFileChooserDialogMethod "add" o = ContainerAddMethodInfo
    ResolveFileChooserDialogMethod "addAccelGroup" o = WindowAddAccelGroupMethodInfo
    ResolveFileChooserDialogMethod "addAccelerator" o = WidgetAddAcceleratorMethodInfo
    ResolveFileChooserDialogMethod "addActionWidget" o = DialogAddActionWidgetMethodInfo
    ResolveFileChooserDialogMethod "addButton" o = DialogAddButtonMethodInfo
    ResolveFileChooserDialogMethod "addChild" o = BuildableAddChildMethodInfo
    ResolveFileChooserDialogMethod "addDeviceEvents" o = WidgetAddDeviceEventsMethodInfo
    ResolveFileChooserDialogMethod "addEvents" o = WidgetAddEventsMethodInfo
    ResolveFileChooserDialogMethod "addFilter" o = FileChooserAddFilterMethodInfo
    ResolveFileChooserDialogMethod "addMnemonic" o = WindowAddMnemonicMethodInfo
    ResolveFileChooserDialogMethod "addMnemonicLabel" o = WidgetAddMnemonicLabelMethodInfo
    ResolveFileChooserDialogMethod "addShortcutFolder" o = FileChooserAddShortcutFolderMethodInfo
    ResolveFileChooserDialogMethod "addShortcutFolderUri" o = FileChooserAddShortcutFolderUriMethodInfo
    ResolveFileChooserDialogMethod "addTickCallback" o = WidgetAddTickCallbackMethodInfo
    ResolveFileChooserDialogMethod "beginMoveDrag" o = WindowBeginMoveDragMethodInfo
    ResolveFileChooserDialogMethod "beginResizeDrag" o = WindowBeginResizeDragMethodInfo
    ResolveFileChooserDialogMethod "bindProperty" o = GObject.ObjectBindPropertyMethodInfo
    ResolveFileChooserDialogMethod "bindPropertyFull" o = GObject.ObjectBindPropertyFullMethodInfo
    ResolveFileChooserDialogMethod "canActivateAccel" o = WidgetCanActivateAccelMethodInfo
    ResolveFileChooserDialogMethod "checkResize" o = ContainerCheckResizeMethodInfo
    ResolveFileChooserDialogMethod "childFocus" o = WidgetChildFocusMethodInfo
    ResolveFileChooserDialogMethod "childGetProperty" o = ContainerChildGetPropertyMethodInfo
    ResolveFileChooserDialogMethod "childNotifyByPspec" o = ContainerChildNotifyByPspecMethodInfo
    ResolveFileChooserDialogMethod "childSetProperty" o = ContainerChildSetPropertyMethodInfo
    ResolveFileChooserDialogMethod "childType" o = ContainerChildTypeMethodInfo
    ResolveFileChooserDialogMethod "classPath" o = WidgetClassPathMethodInfo
    ResolveFileChooserDialogMethod "close" o = WindowCloseMethodInfo
    ResolveFileChooserDialogMethod "computeExpand" o = WidgetComputeExpandMethodInfo
    ResolveFileChooserDialogMethod "constructChild" o = BuildableConstructChildMethodInfo
    ResolveFileChooserDialogMethod "createPangoContext" o = WidgetCreatePangoContextMethodInfo
    ResolveFileChooserDialogMethod "createPangoLayout" o = WidgetCreatePangoLayoutMethodInfo
    ResolveFileChooserDialogMethod "customFinished" o = BuildableCustomFinishedMethodInfo
    ResolveFileChooserDialogMethod "customTagEnd" o = BuildableCustomTagEndMethodInfo
    ResolveFileChooserDialogMethod "customTagStart" o = BuildableCustomTagStartMethodInfo
    ResolveFileChooserDialogMethod "deiconify" o = WindowDeiconifyMethodInfo
    ResolveFileChooserDialogMethod "destroy" o = WidgetDestroyMethodInfo
    ResolveFileChooserDialogMethod "destroyed" o = WidgetDestroyedMethodInfo
    ResolveFileChooserDialogMethod "deviceIsShadowed" o = WidgetDeviceIsShadowedMethodInfo
    ResolveFileChooserDialogMethod "dragBegin" o = WidgetDragBeginMethodInfo
    ResolveFileChooserDialogMethod "dragBeginWithCoordinates" o = WidgetDragBeginWithCoordinatesMethodInfo
    ResolveFileChooserDialogMethod "dragCheckThreshold" o = WidgetDragCheckThresholdMethodInfo
    ResolveFileChooserDialogMethod "dragDestAddImageTargets" o = WidgetDragDestAddImageTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragDestAddTextTargets" o = WidgetDragDestAddTextTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragDestAddUriTargets" o = WidgetDragDestAddUriTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragDestFindTarget" o = WidgetDragDestFindTargetMethodInfo
    ResolveFileChooserDialogMethod "dragDestGetTargetList" o = WidgetDragDestGetTargetListMethodInfo
    ResolveFileChooserDialogMethod "dragDestGetTrackMotion" o = WidgetDragDestGetTrackMotionMethodInfo
    ResolveFileChooserDialogMethod "dragDestSet" o = WidgetDragDestSetMethodInfo
    ResolveFileChooserDialogMethod "dragDestSetProxy" o = WidgetDragDestSetProxyMethodInfo
    ResolveFileChooserDialogMethod "dragDestSetTargetList" o = WidgetDragDestSetTargetListMethodInfo
    ResolveFileChooserDialogMethod "dragDestSetTrackMotion" o = WidgetDragDestSetTrackMotionMethodInfo
    ResolveFileChooserDialogMethod "dragDestUnset" o = WidgetDragDestUnsetMethodInfo
    ResolveFileChooserDialogMethod "dragGetData" o = WidgetDragGetDataMethodInfo
    ResolveFileChooserDialogMethod "dragHighlight" o = WidgetDragHighlightMethodInfo
    ResolveFileChooserDialogMethod "dragSourceAddImageTargets" o = WidgetDragSourceAddImageTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragSourceAddTextTargets" o = WidgetDragSourceAddTextTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragSourceAddUriTargets" o = WidgetDragSourceAddUriTargetsMethodInfo
    ResolveFileChooserDialogMethod "dragSourceGetTargetList" o = WidgetDragSourceGetTargetListMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSet" o = WidgetDragSourceSetMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSetIconGicon" o = WidgetDragSourceSetIconGiconMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSetIconName" o = WidgetDragSourceSetIconNameMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSetIconPixbuf" o = WidgetDragSourceSetIconPixbufMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSetIconStock" o = WidgetDragSourceSetIconStockMethodInfo
    ResolveFileChooserDialogMethod "dragSourceSetTargetList" o = WidgetDragSourceSetTargetListMethodInfo
    ResolveFileChooserDialogMethod "dragSourceUnset" o = WidgetDragSourceUnsetMethodInfo
    ResolveFileChooserDialogMethod "dragUnhighlight" o = WidgetDragUnhighlightMethodInfo
    ResolveFileChooserDialogMethod "draw" o = WidgetDrawMethodInfo
    ResolveFileChooserDialogMethod "ensureStyle" o = WidgetEnsureStyleMethodInfo
    ResolveFileChooserDialogMethod "errorBell" o = WidgetErrorBellMethodInfo
    ResolveFileChooserDialogMethod "event" o = WidgetEventMethodInfo
    ResolveFileChooserDialogMethod "forall" o = ContainerForallMethodInfo
    ResolveFileChooserDialogMethod "forceFloating" o = GObject.ObjectForceFloatingMethodInfo
    ResolveFileChooserDialogMethod "foreach" o = ContainerForeachMethodInfo
    ResolveFileChooserDialogMethod "freezeChildNotify" o = WidgetFreezeChildNotifyMethodInfo
    ResolveFileChooserDialogMethod "freezeNotify" o = GObject.ObjectFreezeNotifyMethodInfo
    ResolveFileChooserDialogMethod "fullscreen" o = WindowFullscreenMethodInfo
    ResolveFileChooserDialogMethod "fullscreenOnMonitor" o = WindowFullscreenOnMonitorMethodInfo
    ResolveFileChooserDialogMethod "grabAdd" o = WidgetGrabAddMethodInfo
    ResolveFileChooserDialogMethod "grabDefault" o = WidgetGrabDefaultMethodInfo
    ResolveFileChooserDialogMethod "grabFocus" o = WidgetGrabFocusMethodInfo
    ResolveFileChooserDialogMethod "grabRemove" o = WidgetGrabRemoveMethodInfo
    ResolveFileChooserDialogMethod "hasDefault" o = WidgetHasDefaultMethodInfo
    ResolveFileChooserDialogMethod "hasFocus" o = WidgetHasFocusMethodInfo
    ResolveFileChooserDialogMethod "hasGrab" o = WidgetHasGrabMethodInfo
    ResolveFileChooserDialogMethod "hasGroup" o = WindowHasGroupMethodInfo
    ResolveFileChooserDialogMethod "hasRcStyle" o = WidgetHasRcStyleMethodInfo
    ResolveFileChooserDialogMethod "hasScreen" o = WidgetHasScreenMethodInfo
    ResolveFileChooserDialogMethod "hasToplevelFocus" o = WindowHasToplevelFocusMethodInfo
    ResolveFileChooserDialogMethod "hasVisibleFocus" o = WidgetHasVisibleFocusMethodInfo
    ResolveFileChooserDialogMethod "hide" o = WidgetHideMethodInfo
    ResolveFileChooserDialogMethod "hideOnDelete" o = WidgetHideOnDeleteMethodInfo
    ResolveFileChooserDialogMethod "iconify" o = WindowIconifyMethodInfo
    ResolveFileChooserDialogMethod "inDestruction" o = WidgetInDestructionMethodInfo
    ResolveFileChooserDialogMethod "initTemplate" o = WidgetInitTemplateMethodInfo
    ResolveFileChooserDialogMethod "inputShapeCombineRegion" o = WidgetInputShapeCombineRegionMethodInfo
    ResolveFileChooserDialogMethod "insertActionGroup" o = WidgetInsertActionGroupMethodInfo
    ResolveFileChooserDialogMethod "intersect" o = WidgetIntersectMethodInfo
    ResolveFileChooserDialogMethod "isActive" o = WindowIsActiveMethodInfo
    ResolveFileChooserDialogMethod "isAncestor" o = WidgetIsAncestorMethodInfo
    ResolveFileChooserDialogMethod "isComposited" o = WidgetIsCompositedMethodInfo
    ResolveFileChooserDialogMethod "isDrawable" o = WidgetIsDrawableMethodInfo
    ResolveFileChooserDialogMethod "isFloating" o = GObject.ObjectIsFloatingMethodInfo
    ResolveFileChooserDialogMethod "isFocus" o = WidgetIsFocusMethodInfo
    ResolveFileChooserDialogMethod "isMaximized" o = WindowIsMaximizedMethodInfo
    ResolveFileChooserDialogMethod "isSensitive" o = WidgetIsSensitiveMethodInfo
    ResolveFileChooserDialogMethod "isToplevel" o = WidgetIsToplevelMethodInfo
    ResolveFileChooserDialogMethod "isVisible" o = WidgetIsVisibleMethodInfo
    ResolveFileChooserDialogMethod "keynavFailed" o = WidgetKeynavFailedMethodInfo
    ResolveFileChooserDialogMethod "listAccelClosures" o = WidgetListAccelClosuresMethodInfo
    ResolveFileChooserDialogMethod "listActionPrefixes" o = WidgetListActionPrefixesMethodInfo
    ResolveFileChooserDialogMethod "listFilters" o = FileChooserListFiltersMethodInfo
    ResolveFileChooserDialogMethod "listMnemonicLabels" o = WidgetListMnemonicLabelsMethodInfo
    ResolveFileChooserDialogMethod "listShortcutFolderUris" o = FileChooserListShortcutFolderUrisMethodInfo
    ResolveFileChooserDialogMethod "listShortcutFolders" o = FileChooserListShortcutFoldersMethodInfo
    ResolveFileChooserDialogMethod "map" o = WidgetMapMethodInfo
    ResolveFileChooserDialogMethod "maximize" o = WindowMaximizeMethodInfo
    ResolveFileChooserDialogMethod "modifyBase" o = WidgetModifyBaseMethodInfo
    ResolveFileChooserDialogMethod "modifyBg" o = WidgetModifyBgMethodInfo
    ResolveFileChooserDialogMethod "modifyCursor" o = WidgetModifyCursorMethodInfo
    ResolveFileChooserDialogMethod "modifyFg" o = WidgetModifyFgMethodInfo
    ResolveFileChooserDialogMethod "modifyFont" o = WidgetModifyFontMethodInfo
    ResolveFileChooserDialogMethod "modifyStyle" o = WidgetModifyStyleMethodInfo
    ResolveFileChooserDialogMethod "modifyText" o = WidgetModifyTextMethodInfo
    ResolveFileChooserDialogMethod "move" o = WindowMoveMethodInfo
    ResolveFileChooserDialogMethod "notify" o = GObject.ObjectNotifyMethodInfo
    ResolveFileChooserDialogMethod "notifyByPspec" o = GObject.ObjectNotifyByPspecMethodInfo
    ResolveFileChooserDialogMethod "overrideBackgroundColor" o = WidgetOverrideBackgroundColorMethodInfo
    ResolveFileChooserDialogMethod "overrideColor" o = WidgetOverrideColorMethodInfo
    ResolveFileChooserDialogMethod "overrideCursor" o = WidgetOverrideCursorMethodInfo
    ResolveFileChooserDialogMethod "overrideFont" o = WidgetOverrideFontMethodInfo
    ResolveFileChooserDialogMethod "overrideSymbolicColor" o = WidgetOverrideSymbolicColorMethodInfo
    ResolveFileChooserDialogMethod "parseGeometry" o = WindowParseGeometryMethodInfo
    ResolveFileChooserDialogMethod "parserFinished" o = BuildableParserFinishedMethodInfo
    ResolveFileChooserDialogMethod "path" o = WidgetPathMethodInfo
    ResolveFileChooserDialogMethod "present" o = WindowPresentMethodInfo
    ResolveFileChooserDialogMethod "presentWithTime" o = WindowPresentWithTimeMethodInfo
    ResolveFileChooserDialogMethod "propagateDraw" o = ContainerPropagateDrawMethodInfo
    ResolveFileChooserDialogMethod "propagateKeyEvent" o = WindowPropagateKeyEventMethodInfo
    ResolveFileChooserDialogMethod "queueComputeExpand" o = WidgetQueueComputeExpandMethodInfo
    ResolveFileChooserDialogMethod "queueDraw" o = WidgetQueueDrawMethodInfo
    ResolveFileChooserDialogMethod "queueDrawArea" o = WidgetQueueDrawAreaMethodInfo
    ResolveFileChooserDialogMethod "queueDrawRegion" o = WidgetQueueDrawRegionMethodInfo
    ResolveFileChooserDialogMethod "queueResize" o = WidgetQueueResizeMethodInfo
    ResolveFileChooserDialogMethod "queueResizeNoRedraw" o = WidgetQueueResizeNoRedrawMethodInfo
    ResolveFileChooserDialogMethod "realize" o = WidgetRealizeMethodInfo
    ResolveFileChooserDialogMethod "ref" o = GObject.ObjectRefMethodInfo
    ResolveFileChooserDialogMethod "refSink" o = GObject.ObjectRefSinkMethodInfo
    ResolveFileChooserDialogMethod "regionIntersect" o = WidgetRegionIntersectMethodInfo
    ResolveFileChooserDialogMethod "registerWindow" o = WidgetRegisterWindowMethodInfo
    ResolveFileChooserDialogMethod "remove" o = ContainerRemoveMethodInfo
    ResolveFileChooserDialogMethod "removeAccelGroup" o = WindowRemoveAccelGroupMethodInfo
    ResolveFileChooserDialogMethod "removeAccelerator" o = WidgetRemoveAcceleratorMethodInfo
    ResolveFileChooserDialogMethod "removeFilter" o = FileChooserRemoveFilterMethodInfo
    ResolveFileChooserDialogMethod "removeMnemonic" o = WindowRemoveMnemonicMethodInfo
    ResolveFileChooserDialogMethod "removeMnemonicLabel" o = WidgetRemoveMnemonicLabelMethodInfo
    ResolveFileChooserDialogMethod "removeShortcutFolder" o = FileChooserRemoveShortcutFolderMethodInfo
    ResolveFileChooserDialogMethod "removeShortcutFolderUri" o = FileChooserRemoveShortcutFolderUriMethodInfo
    ResolveFileChooserDialogMethod "removeTickCallback" o = WidgetRemoveTickCallbackMethodInfo
    ResolveFileChooserDialogMethod "renderIcon" o = WidgetRenderIconMethodInfo
    ResolveFileChooserDialogMethod "renderIconPixbuf" o = WidgetRenderIconPixbufMethodInfo
    ResolveFileChooserDialogMethod "reparent" o = WidgetReparentMethodInfo
    ResolveFileChooserDialogMethod "replaceData" o = GObject.ObjectReplaceDataMethodInfo
    ResolveFileChooserDialogMethod "replaceQdata" o = GObject.ObjectReplaceQdataMethodInfo
    ResolveFileChooserDialogMethod "resetRcStyles" o = WidgetResetRcStylesMethodInfo
    ResolveFileChooserDialogMethod "resetStyle" o = WidgetResetStyleMethodInfo
    ResolveFileChooserDialogMethod "reshowWithInitialSize" o = WindowReshowWithInitialSizeMethodInfo
    ResolveFileChooserDialogMethod "resize" o = WindowResizeMethodInfo
    ResolveFileChooserDialogMethod "resizeChildren" o = ContainerResizeChildrenMethodInfo
    ResolveFileChooserDialogMethod "resizeGripIsVisible" o = WindowResizeGripIsVisibleMethodInfo
    ResolveFileChooserDialogMethod "resizeToGeometry" o = WindowResizeToGeometryMethodInfo
    ResolveFileChooserDialogMethod "response" o = DialogResponseMethodInfo
    ResolveFileChooserDialogMethod "run" o = DialogRunMethodInfo
    ResolveFileChooserDialogMethod "runDispose" o = GObject.ObjectRunDisposeMethodInfo
    ResolveFileChooserDialogMethod "selectAll" o = FileChooserSelectAllMethodInfo
    ResolveFileChooserDialogMethod "selectFile" o = FileChooserSelectFileMethodInfo
    ResolveFileChooserDialogMethod "selectFilename" o = FileChooserSelectFilenameMethodInfo
    ResolveFileChooserDialogMethod "selectUri" o = FileChooserSelectUriMethodInfo
    ResolveFileChooserDialogMethod "sendExpose" o = WidgetSendExposeMethodInfo
    ResolveFileChooserDialogMethod "sendFocusChange" o = WidgetSendFocusChangeMethodInfo
    ResolveFileChooserDialogMethod "shapeCombineRegion" o = WidgetShapeCombineRegionMethodInfo
    ResolveFileChooserDialogMethod "show" o = WidgetShowMethodInfo
    ResolveFileChooserDialogMethod "showAll" o = WidgetShowAllMethodInfo
    ResolveFileChooserDialogMethod "showNow" o = WidgetShowNowMethodInfo
    ResolveFileChooserDialogMethod "sizeAllocate" o = WidgetSizeAllocateMethodInfo
    ResolveFileChooserDialogMethod "sizeAllocateWithBaseline" o = WidgetSizeAllocateWithBaselineMethodInfo
    ResolveFileChooserDialogMethod "sizeRequest" o = WidgetSizeRequestMethodInfo
    ResolveFileChooserDialogMethod "stealData" o = GObject.ObjectStealDataMethodInfo
    ResolveFileChooserDialogMethod "stealQdata" o = GObject.ObjectStealQdataMethodInfo
    ResolveFileChooserDialogMethod "stick" o = WindowStickMethodInfo
    ResolveFileChooserDialogMethod "styleAttach" o = WidgetStyleAttachMethodInfo
    ResolveFileChooserDialogMethod "styleGetProperty" o = WidgetStyleGetPropertyMethodInfo
    ResolveFileChooserDialogMethod "thawChildNotify" o = WidgetThawChildNotifyMethodInfo
    ResolveFileChooserDialogMethod "thawNotify" o = GObject.ObjectThawNotifyMethodInfo
    ResolveFileChooserDialogMethod "translateCoordinates" o = WidgetTranslateCoordinatesMethodInfo
    ResolveFileChooserDialogMethod "triggerTooltipQuery" o = WidgetTriggerTooltipQueryMethodInfo
    ResolveFileChooserDialogMethod "unfullscreen" o = WindowUnfullscreenMethodInfo
    ResolveFileChooserDialogMethod "unmap" o = WidgetUnmapMethodInfo
    ResolveFileChooserDialogMethod "unmaximize" o = WindowUnmaximizeMethodInfo
    ResolveFileChooserDialogMethod "unparent" o = WidgetUnparentMethodInfo
    ResolveFileChooserDialogMethod "unrealize" o = WidgetUnrealizeMethodInfo
    ResolveFileChooserDialogMethod "unref" o = GObject.ObjectUnrefMethodInfo
    ResolveFileChooserDialogMethod "unregisterWindow" o = WidgetUnregisterWindowMethodInfo
    ResolveFileChooserDialogMethod "unselectAll" o = FileChooserUnselectAllMethodInfo
    ResolveFileChooserDialogMethod "unselectFile" o = FileChooserUnselectFileMethodInfo
    ResolveFileChooserDialogMethod "unselectFilename" o = FileChooserUnselectFilenameMethodInfo
    ResolveFileChooserDialogMethod "unselectUri" o = FileChooserUnselectUriMethodInfo
    ResolveFileChooserDialogMethod "unsetFocusChain" o = ContainerUnsetFocusChainMethodInfo
    ResolveFileChooserDialogMethod "unsetStateFlags" o = WidgetUnsetStateFlagsMethodInfo
    ResolveFileChooserDialogMethod "unstick" o = WindowUnstickMethodInfo
    ResolveFileChooserDialogMethod "watchClosure" o = GObject.ObjectWatchClosureMethodInfo
    ResolveFileChooserDialogMethod "getAcceptFocus" o = WindowGetAcceptFocusMethodInfo
    ResolveFileChooserDialogMethod "getAccessible" o = WidgetGetAccessibleMethodInfo
    ResolveFileChooserDialogMethod "getAction" o = FileChooserGetActionMethodInfo
    ResolveFileChooserDialogMethod "getActionArea" o = DialogGetActionAreaMethodInfo
    ResolveFileChooserDialogMethod "getActionGroup" o = WidgetGetActionGroupMethodInfo
    ResolveFileChooserDialogMethod "getAllocatedBaseline" o = WidgetGetAllocatedBaselineMethodInfo
    ResolveFileChooserDialogMethod "getAllocatedHeight" o = WidgetGetAllocatedHeightMethodInfo
    ResolveFileChooserDialogMethod "getAllocatedWidth" o = WidgetGetAllocatedWidthMethodInfo
    ResolveFileChooserDialogMethod "getAllocation" o = WidgetGetAllocationMethodInfo
    ResolveFileChooserDialogMethod "getAncestor" o = WidgetGetAncestorMethodInfo
    ResolveFileChooserDialogMethod "getAppPaintable" o = WidgetGetAppPaintableMethodInfo
    ResolveFileChooserDialogMethod "getApplication" o = WindowGetApplicationMethodInfo
    ResolveFileChooserDialogMethod "getAttachedTo" o = WindowGetAttachedToMethodInfo
    ResolveFileChooserDialogMethod "getBorderWidth" o = ContainerGetBorderWidthMethodInfo
    ResolveFileChooserDialogMethod "getCanDefault" o = WidgetGetCanDefaultMethodInfo
    ResolveFileChooserDialogMethod "getCanFocus" o = WidgetGetCanFocusMethodInfo
    ResolveFileChooserDialogMethod "getChild" o = BinGetChildMethodInfo
    ResolveFileChooserDialogMethod "getChildRequisition" o = WidgetGetChildRequisitionMethodInfo
    ResolveFileChooserDialogMethod "getChildVisible" o = WidgetGetChildVisibleMethodInfo
    ResolveFileChooserDialogMethod "getChildren" o = ContainerGetChildrenMethodInfo
    ResolveFileChooserDialogMethod "getClip" o = WidgetGetClipMethodInfo
    ResolveFileChooserDialogMethod "getClipboard" o = WidgetGetClipboardMethodInfo
    ResolveFileChooserDialogMethod "getCompositeName" o = WidgetGetCompositeNameMethodInfo
    ResolveFileChooserDialogMethod "getContentArea" o = DialogGetContentAreaMethodInfo
    ResolveFileChooserDialogMethod "getCreateFolders" o = FileChooserGetCreateFoldersMethodInfo
    ResolveFileChooserDialogMethod "getCurrentFolder" o = FileChooserGetCurrentFolderMethodInfo
    ResolveFileChooserDialogMethod "getCurrentFolderFile" o = FileChooserGetCurrentFolderFileMethodInfo
    ResolveFileChooserDialogMethod "getCurrentFolderUri" o = FileChooserGetCurrentFolderUriMethodInfo
    ResolveFileChooserDialogMethod "getCurrentName" o = FileChooserGetCurrentNameMethodInfo
    ResolveFileChooserDialogMethod "getData" o = GObject.ObjectGetDataMethodInfo
    ResolveFileChooserDialogMethod "getDecorated" o = WindowGetDecoratedMethodInfo
    ResolveFileChooserDialogMethod "getDefaultSize" o = WindowGetDefaultSizeMethodInfo
    ResolveFileChooserDialogMethod "getDefaultWidget" o = WindowGetDefaultWidgetMethodInfo
    ResolveFileChooserDialogMethod "getDeletable" o = WindowGetDeletableMethodInfo
    ResolveFileChooserDialogMethod "getDestroyWithParent" o = WindowGetDestroyWithParentMethodInfo
    ResolveFileChooserDialogMethod "getDeviceEnabled" o = WidgetGetDeviceEnabledMethodInfo
    ResolveFileChooserDialogMethod "getDeviceEvents" o = WidgetGetDeviceEventsMethodInfo
    ResolveFileChooserDialogMethod "getDirection" o = WidgetGetDirectionMethodInfo
    ResolveFileChooserDialogMethod "getDisplay" o = WidgetGetDisplayMethodInfo
    ResolveFileChooserDialogMethod "getDoOverwriteConfirmation" o = FileChooserGetDoOverwriteConfirmationMethodInfo
    ResolveFileChooserDialogMethod "getDoubleBuffered" o = WidgetGetDoubleBufferedMethodInfo
    ResolveFileChooserDialogMethod "getEvents" o = WidgetGetEventsMethodInfo
    ResolveFileChooserDialogMethod "getExtraWidget" o = FileChooserGetExtraWidgetMethodInfo
    ResolveFileChooserDialogMethod "getFile" o = FileChooserGetFileMethodInfo
    ResolveFileChooserDialogMethod "getFilename" o = FileChooserGetFilenameMethodInfo
    ResolveFileChooserDialogMethod "getFilenames" o = FileChooserGetFilenamesMethodInfo
    ResolveFileChooserDialogMethod "getFiles" o = FileChooserGetFilesMethodInfo
    ResolveFileChooserDialogMethod "getFilter" o = FileChooserGetFilterMethodInfo
    ResolveFileChooserDialogMethod "getFocus" o = WindowGetFocusMethodInfo
    ResolveFileChooserDialogMethod "getFocusChain" o = ContainerGetFocusChainMethodInfo
    ResolveFileChooserDialogMethod "getFocusChild" o = ContainerGetFocusChildMethodInfo
    ResolveFileChooserDialogMethod "getFocusHadjustment" o = ContainerGetFocusHadjustmentMethodInfo
    ResolveFileChooserDialogMethod "getFocusOnMap" o = WindowGetFocusOnMapMethodInfo
    ResolveFileChooserDialogMethod "getFocusVadjustment" o = ContainerGetFocusVadjustmentMethodInfo
    ResolveFileChooserDialogMethod "getFocusVisible" o = WindowGetFocusVisibleMethodInfo
    ResolveFileChooserDialogMethod "getFontMap" o = WidgetGetFontMapMethodInfo
    ResolveFileChooserDialogMethod "getFontOptions" o = WidgetGetFontOptionsMethodInfo
    ResolveFileChooserDialogMethod "getFrameClock" o = WidgetGetFrameClockMethodInfo
    ResolveFileChooserDialogMethod "getGravity" o = WindowGetGravityMethodInfo
    ResolveFileChooserDialogMethod "getGroup" o = WindowGetGroupMethodInfo
    ResolveFileChooserDialogMethod "getHalign" o = WidgetGetHalignMethodInfo
    ResolveFileChooserDialogMethod "getHasResizeGrip" o = WindowGetHasResizeGripMethodInfo
    ResolveFileChooserDialogMethod "getHasTooltip" o = WidgetGetHasTooltipMethodInfo
    ResolveFileChooserDialogMethod "getHasWindow" o = WidgetGetHasWindowMethodInfo
    ResolveFileChooserDialogMethod "getHeaderBar" o = DialogGetHeaderBarMethodInfo
    ResolveFileChooserDialogMethod "getHexpand" o = WidgetGetHexpandMethodInfo
    ResolveFileChooserDialogMethod "getHexpandSet" o = WidgetGetHexpandSetMethodInfo
    ResolveFileChooserDialogMethod "getHideTitlebarWhenMaximized" o = WindowGetHideTitlebarWhenMaximizedMethodInfo
    ResolveFileChooserDialogMethod "getIcon" o = WindowGetIconMethodInfo
    ResolveFileChooserDialogMethod "getIconList" o = WindowGetIconListMethodInfo
    ResolveFileChooserDialogMethod "getIconName" o = WindowGetIconNameMethodInfo
    ResolveFileChooserDialogMethod "getInternalChild" o = BuildableGetInternalChildMethodInfo
    ResolveFileChooserDialogMethod "getLocalOnly" o = FileChooserGetLocalOnlyMethodInfo
    ResolveFileChooserDialogMethod "getMapped" o = WidgetGetMappedMethodInfo
    ResolveFileChooserDialogMethod "getMarginBottom" o = WidgetGetMarginBottomMethodInfo
    ResolveFileChooserDialogMethod "getMarginEnd" o = WidgetGetMarginEndMethodInfo
    ResolveFileChooserDialogMethod "getMarginLeft" o = WidgetGetMarginLeftMethodInfo
    ResolveFileChooserDialogMethod "getMarginRight" o = WidgetGetMarginRightMethodInfo
    ResolveFileChooserDialogMethod "getMarginStart" o = WidgetGetMarginStartMethodInfo
    ResolveFileChooserDialogMethod "getMarginTop" o = WidgetGetMarginTopMethodInfo
    ResolveFileChooserDialogMethod "getMnemonicModifier" o = WindowGetMnemonicModifierMethodInfo
    ResolveFileChooserDialogMethod "getMnemonicsVisible" o = WindowGetMnemonicsVisibleMethodInfo
    ResolveFileChooserDialogMethod "getModal" o = WindowGetModalMethodInfo
    ResolveFileChooserDialogMethod "getModifierMask" o = WidgetGetModifierMaskMethodInfo
    ResolveFileChooserDialogMethod "getModifierStyle" o = WidgetGetModifierStyleMethodInfo
    ResolveFileChooserDialogMethod "getNoShowAll" o = WidgetGetNoShowAllMethodInfo
    ResolveFileChooserDialogMethod "getPangoContext" o = WidgetGetPangoContextMethodInfo
    ResolveFileChooserDialogMethod "getParent" o = WidgetGetParentMethodInfo
    ResolveFileChooserDialogMethod "getParentWindow" o = WidgetGetParentWindowMethodInfo
    ResolveFileChooserDialogMethod "getPath" o = WidgetGetPathMethodInfo
    ResolveFileChooserDialogMethod "getPathForChild" o = ContainerGetPathForChildMethodInfo
    ResolveFileChooserDialogMethod "getPointer" o = WidgetGetPointerMethodInfo
    ResolveFileChooserDialogMethod "getPosition" o = WindowGetPositionMethodInfo
    ResolveFileChooserDialogMethod "getPreferredHeight" o = WidgetGetPreferredHeightMethodInfo
    ResolveFileChooserDialogMethod "getPreferredHeightAndBaselineForWidth" o = WidgetGetPreferredHeightAndBaselineForWidthMethodInfo
    ResolveFileChooserDialogMethod "getPreferredHeightForWidth" o = WidgetGetPreferredHeightForWidthMethodInfo
    ResolveFileChooserDialogMethod "getPreferredSize" o = WidgetGetPreferredSizeMethodInfo
    ResolveFileChooserDialogMethod "getPreferredWidth" o = WidgetGetPreferredWidthMethodInfo
    ResolveFileChooserDialogMethod "getPreferredWidthForHeight" o = WidgetGetPreferredWidthForHeightMethodInfo
    ResolveFileChooserDialogMethod "getPreviewFile" o = FileChooserGetPreviewFileMethodInfo
    ResolveFileChooserDialogMethod "getPreviewFilename" o = FileChooserGetPreviewFilenameMethodInfo
    ResolveFileChooserDialogMethod "getPreviewUri" o = FileChooserGetPreviewUriMethodInfo
    ResolveFileChooserDialogMethod "getPreviewWidget" o = FileChooserGetPreviewWidgetMethodInfo
    ResolveFileChooserDialogMethod "getPreviewWidgetActive" o = FileChooserGetPreviewWidgetActiveMethodInfo
    ResolveFileChooserDialogMethod "getProperty" o = GObject.ObjectGetPropertyMethodInfo
    ResolveFileChooserDialogMethod "getQdata" o = GObject.ObjectGetQdataMethodInfo
    ResolveFileChooserDialogMethod "getRealized" o = WidgetGetRealizedMethodInfo
    ResolveFileChooserDialogMethod "getReceivesDefault" o = WidgetGetReceivesDefaultMethodInfo
    ResolveFileChooserDialogMethod "getRequestMode" o = WidgetGetRequestModeMethodInfo
    ResolveFileChooserDialogMethod "getRequisition" o = WidgetGetRequisitionMethodInfo
    ResolveFileChooserDialogMethod "getResizable" o = WindowGetResizableMethodInfo
    ResolveFileChooserDialogMethod "getResizeGripArea" o = WindowGetResizeGripAreaMethodInfo
    ResolveFileChooserDialogMethod "getResizeMode" o = ContainerGetResizeModeMethodInfo
    ResolveFileChooserDialogMethod "getResponseForWidget" o = DialogGetResponseForWidgetMethodInfo
    ResolveFileChooserDialogMethod "getRole" o = WindowGetRoleMethodInfo
    ResolveFileChooserDialogMethod "getRootWindow" o = WidgetGetRootWindowMethodInfo
    ResolveFileChooserDialogMethod "getScaleFactor" o = WidgetGetScaleFactorMethodInfo
    ResolveFileChooserDialogMethod "getSelectMultiple" o = FileChooserGetSelectMultipleMethodInfo
    ResolveFileChooserDialogMethod "getSensitive" o = WidgetGetSensitiveMethodInfo
    ResolveFileChooserDialogMethod "getSettings" o = WidgetGetSettingsMethodInfo
    ResolveFileChooserDialogMethod "getShowHidden" o = FileChooserGetShowHiddenMethodInfo
    ResolveFileChooserDialogMethod "getSize" o = WindowGetSizeMethodInfo
    ResolveFileChooserDialogMethod "getSizeRequest" o = WidgetGetSizeRequestMethodInfo
    ResolveFileChooserDialogMethod "getSkipPagerHint" o = WindowGetSkipPagerHintMethodInfo
    ResolveFileChooserDialogMethod "getSkipTaskbarHint" o = WindowGetSkipTaskbarHintMethodInfo
    ResolveFileChooserDialogMethod "getState" o = WidgetGetStateMethodInfo
    ResolveFileChooserDialogMethod "getStateFlags" o = WidgetGetStateFlagsMethodInfo
    ResolveFileChooserDialogMethod "getStyle" o = WidgetGetStyleMethodInfo
    ResolveFileChooserDialogMethod "getStyleContext" o = WidgetGetStyleContextMethodInfo
    ResolveFileChooserDialogMethod "getSupportMultidevice" o = WidgetGetSupportMultideviceMethodInfo
    ResolveFileChooserDialogMethod "getTemplateChild" o = WidgetGetTemplateChildMethodInfo
    ResolveFileChooserDialogMethod "getTitle" o = WindowGetTitleMethodInfo
    ResolveFileChooserDialogMethod "getTitlebar" o = WindowGetTitlebarMethodInfo
    ResolveFileChooserDialogMethod "getTooltipMarkup" o = WidgetGetTooltipMarkupMethodInfo
    ResolveFileChooserDialogMethod "getTooltipText" o = WidgetGetTooltipTextMethodInfo
    ResolveFileChooserDialogMethod "getTooltipWindow" o = WidgetGetTooltipWindowMethodInfo
    ResolveFileChooserDialogMethod "getToplevel" o = WidgetGetToplevelMethodInfo
    ResolveFileChooserDialogMethod "getTransientFor" o = WindowGetTransientForMethodInfo
    ResolveFileChooserDialogMethod "getTypeHint" o = WindowGetTypeHintMethodInfo
    ResolveFileChooserDialogMethod "getUrgencyHint" o = WindowGetUrgencyHintMethodInfo
    ResolveFileChooserDialogMethod "getUri" o = FileChooserGetUriMethodInfo
    ResolveFileChooserDialogMethod "getUris" o = FileChooserGetUrisMethodInfo
    ResolveFileChooserDialogMethod "getUsePreviewLabel" o = FileChooserGetUsePreviewLabelMethodInfo
    ResolveFileChooserDialogMethod "getValign" o = WidgetGetValignMethodInfo
    ResolveFileChooserDialogMethod "getValignWithBaseline" o = WidgetGetValignWithBaselineMethodInfo
    ResolveFileChooserDialogMethod "getVexpand" o = WidgetGetVexpandMethodInfo
    ResolveFileChooserDialogMethod "getVexpandSet" o = WidgetGetVexpandSetMethodInfo
    ResolveFileChooserDialogMethod "getVisible" o = WidgetGetVisibleMethodInfo
    ResolveFileChooserDialogMethod "getVisual" o = WidgetGetVisualMethodInfo
    ResolveFileChooserDialogMethod "getWidgetForResponse" o = DialogGetWidgetForResponseMethodInfo
    ResolveFileChooserDialogMethod "getWindow" o = WidgetGetWindowMethodInfo
    ResolveFileChooserDialogMethod "getWindowType" o = WindowGetWindowTypeMethodInfo
    ResolveFileChooserDialogMethod "setAccelPath" o = WidgetSetAccelPathMethodInfo
    ResolveFileChooserDialogMethod "setAcceptFocus" o = WindowSetAcceptFocusMethodInfo
    ResolveFileChooserDialogMethod "setAction" o = FileChooserSetActionMethodInfo
    ResolveFileChooserDialogMethod "setAllocation" o = WidgetSetAllocationMethodInfo
    ResolveFileChooserDialogMethod "setAlternativeButtonOrderFromArray" o = DialogSetAlternativeButtonOrderFromArrayMethodInfo
    ResolveFileChooserDialogMethod "setAppPaintable" o = WidgetSetAppPaintableMethodInfo
    ResolveFileChooserDialogMethod "setApplication" o = WindowSetApplicationMethodInfo
    ResolveFileChooserDialogMethod "setAttachedTo" o = WindowSetAttachedToMethodInfo
    ResolveFileChooserDialogMethod "setBorderWidth" o = ContainerSetBorderWidthMethodInfo
    ResolveFileChooserDialogMethod "setBuildableProperty" o = BuildableSetBuildablePropertyMethodInfo
    ResolveFileChooserDialogMethod "setCanDefault" o = WidgetSetCanDefaultMethodInfo
    ResolveFileChooserDialogMethod "setCanFocus" o = WidgetSetCanFocusMethodInfo
    ResolveFileChooserDialogMethod "setChildVisible" o = WidgetSetChildVisibleMethodInfo
    ResolveFileChooserDialogMethod "setClip" o = WidgetSetClipMethodInfo
    ResolveFileChooserDialogMethod "setCompositeName" o = WidgetSetCompositeNameMethodInfo
    ResolveFileChooserDialogMethod "setCreateFolders" o = FileChooserSetCreateFoldersMethodInfo
    ResolveFileChooserDialogMethod "setCurrentFolder" o = FileChooserSetCurrentFolderMethodInfo
    ResolveFileChooserDialogMethod "setCurrentFolderFile" o = FileChooserSetCurrentFolderFileMethodInfo
    ResolveFileChooserDialogMethod "setCurrentFolderUri" o = FileChooserSetCurrentFolderUriMethodInfo
    ResolveFileChooserDialogMethod "setCurrentName" o = FileChooserSetCurrentNameMethodInfo
    ResolveFileChooserDialogMethod "setData" o = GObject.ObjectSetDataMethodInfo
    ResolveFileChooserDialogMethod "setDecorated" o = WindowSetDecoratedMethodInfo
    ResolveFileChooserDialogMethod "setDefault" o = WindowSetDefaultMethodInfo
    ResolveFileChooserDialogMethod "setDefaultGeometry" o = WindowSetDefaultGeometryMethodInfo
    ResolveFileChooserDialogMethod "setDefaultResponse" o = DialogSetDefaultResponseMethodInfo
    ResolveFileChooserDialogMethod "setDefaultSize" o = WindowSetDefaultSizeMethodInfo
    ResolveFileChooserDialogMethod "setDeletable" o = WindowSetDeletableMethodInfo
    ResolveFileChooserDialogMethod "setDestroyWithParent" o = WindowSetDestroyWithParentMethodInfo
    ResolveFileChooserDialogMethod "setDeviceEnabled" o = WidgetSetDeviceEnabledMethodInfo
    ResolveFileChooserDialogMethod "setDeviceEvents" o = WidgetSetDeviceEventsMethodInfo
    ResolveFileChooserDialogMethod "setDirection" o = WidgetSetDirectionMethodInfo
    ResolveFileChooserDialogMethod "setDoOverwriteConfirmation" o = FileChooserSetDoOverwriteConfirmationMethodInfo
    ResolveFileChooserDialogMethod "setDoubleBuffered" o = WidgetSetDoubleBufferedMethodInfo
    ResolveFileChooserDialogMethod "setEvents" o = WidgetSetEventsMethodInfo
    ResolveFileChooserDialogMethod "setExtraWidget" o = FileChooserSetExtraWidgetMethodInfo
    ResolveFileChooserDialogMethod "setFile" o = FileChooserSetFileMethodInfo
    ResolveFileChooserDialogMethod "setFilename" o = FileChooserSetFilenameMethodInfo
    ResolveFileChooserDialogMethod "setFilter" o = FileChooserSetFilterMethodInfo
    ResolveFileChooserDialogMethod "setFocus" o = WindowSetFocusMethodInfo
    ResolveFileChooserDialogMethod "setFocusChain" o = ContainerSetFocusChainMethodInfo
    ResolveFileChooserDialogMethod "setFocusChild" o = ContainerSetFocusChildMethodInfo
    ResolveFileChooserDialogMethod "setFocusHadjustment" o = ContainerSetFocusHadjustmentMethodInfo
    ResolveFileChooserDialogMethod "setFocusOnMap" o = WindowSetFocusOnMapMethodInfo
    ResolveFileChooserDialogMethod "setFocusVadjustment" o = ContainerSetFocusVadjustmentMethodInfo
    ResolveFileChooserDialogMethod "setFocusVisible" o = WindowSetFocusVisibleMethodInfo
    ResolveFileChooserDialogMethod "setFontMap" o = WidgetSetFontMapMethodInfo
    ResolveFileChooserDialogMethod "setFontOptions" o = WidgetSetFontOptionsMethodInfo
    ResolveFileChooserDialogMethod "setGeometryHints" o = WindowSetGeometryHintsMethodInfo
    ResolveFileChooserDialogMethod "setGravity" o = WindowSetGravityMethodInfo
    ResolveFileChooserDialogMethod "setHalign" o = WidgetSetHalignMethodInfo
    ResolveFileChooserDialogMethod "setHasResizeGrip" o = WindowSetHasResizeGripMethodInfo
    ResolveFileChooserDialogMethod "setHasTooltip" o = WidgetSetHasTooltipMethodInfo
    ResolveFileChooserDialogMethod "setHasUserRefCount" o = WindowSetHasUserRefCountMethodInfo
    ResolveFileChooserDialogMethod "setHasWindow" o = WidgetSetHasWindowMethodInfo
    ResolveFileChooserDialogMethod "setHexpand" o = WidgetSetHexpandMethodInfo
    ResolveFileChooserDialogMethod "setHexpandSet" o = WidgetSetHexpandSetMethodInfo
    ResolveFileChooserDialogMethod "setHideTitlebarWhenMaximized" o = WindowSetHideTitlebarWhenMaximizedMethodInfo
    ResolveFileChooserDialogMethod "setIcon" o = WindowSetIconMethodInfo
    ResolveFileChooserDialogMethod "setIconFromFile" o = WindowSetIconFromFileMethodInfo
    ResolveFileChooserDialogMethod "setIconList" o = WindowSetIconListMethodInfo
    ResolveFileChooserDialogMethod "setIconName" o = WindowSetIconNameMethodInfo
    ResolveFileChooserDialogMethod "setKeepAbove" o = WindowSetKeepAboveMethodInfo
    ResolveFileChooserDialogMethod "setKeepBelow" o = WindowSetKeepBelowMethodInfo
    ResolveFileChooserDialogMethod "setLocalOnly" o = FileChooserSetLocalOnlyMethodInfo
    ResolveFileChooserDialogMethod "setMapped" o = WidgetSetMappedMethodInfo
    ResolveFileChooserDialogMethod "setMarginBottom" o = WidgetSetMarginBottomMethodInfo
    ResolveFileChooserDialogMethod "setMarginEnd" o = WidgetSetMarginEndMethodInfo
    ResolveFileChooserDialogMethod "setMarginLeft" o = WidgetSetMarginLeftMethodInfo
    ResolveFileChooserDialogMethod "setMarginRight" o = WidgetSetMarginRightMethodInfo
    ResolveFileChooserDialogMethod "setMarginStart" o = WidgetSetMarginStartMethodInfo
    ResolveFileChooserDialogMethod "setMarginTop" o = WidgetSetMarginTopMethodInfo
    ResolveFileChooserDialogMethod "setMnemonicModifier" o = WindowSetMnemonicModifierMethodInfo
    ResolveFileChooserDialogMethod "setMnemonicsVisible" o = WindowSetMnemonicsVisibleMethodInfo
    ResolveFileChooserDialogMethod "setModal" o = WindowSetModalMethodInfo
    ResolveFileChooserDialogMethod "setNoShowAll" o = WidgetSetNoShowAllMethodInfo
    ResolveFileChooserDialogMethod "setParent" o = WidgetSetParentMethodInfo
    ResolveFileChooserDialogMethod "setParentWindow" o = WidgetSetParentWindowMethodInfo
    ResolveFileChooserDialogMethod "setPosition" o = WindowSetPositionMethodInfo
    ResolveFileChooserDialogMethod "setPreviewWidget" o = FileChooserSetPreviewWidgetMethodInfo
    ResolveFileChooserDialogMethod "setPreviewWidgetActive" o = FileChooserSetPreviewWidgetActiveMethodInfo
    ResolveFileChooserDialogMethod "setProperty" o = GObject.ObjectSetPropertyMethodInfo
    ResolveFileChooserDialogMethod "setRealized" o = WidgetSetRealizedMethodInfo
    ResolveFileChooserDialogMethod "setReallocateRedraws" o = ContainerSetReallocateRedrawsMethodInfo
    ResolveFileChooserDialogMethod "setReceivesDefault" o = WidgetSetReceivesDefaultMethodInfo
    ResolveFileChooserDialogMethod "setRedrawOnAllocate" o = WidgetSetRedrawOnAllocateMethodInfo
    ResolveFileChooserDialogMethod "setResizable" o = WindowSetResizableMethodInfo
    ResolveFileChooserDialogMethod "setResizeMode" o = ContainerSetResizeModeMethodInfo
    ResolveFileChooserDialogMethod "setResponseSensitive" o = DialogSetResponseSensitiveMethodInfo
    ResolveFileChooserDialogMethod "setRole" o = WindowSetRoleMethodInfo
    ResolveFileChooserDialogMethod "setScreen" o = WindowSetScreenMethodInfo
    ResolveFileChooserDialogMethod "setSelectMultiple" o = FileChooserSetSelectMultipleMethodInfo
    ResolveFileChooserDialogMethod "setSensitive" o = WidgetSetSensitiveMethodInfo
    ResolveFileChooserDialogMethod "setShowHidden" o = FileChooserSetShowHiddenMethodInfo
    ResolveFileChooserDialogMethod "setSizeRequest" o = WidgetSetSizeRequestMethodInfo
    ResolveFileChooserDialogMethod "setSkipPagerHint" o = WindowSetSkipPagerHintMethodInfo
    ResolveFileChooserDialogMethod "setSkipTaskbarHint" o = WindowSetSkipTaskbarHintMethodInfo
    ResolveFileChooserDialogMethod "setStartupId" o = WindowSetStartupIdMethodInfo
    ResolveFileChooserDialogMethod "setState" o = WidgetSetStateMethodInfo
    ResolveFileChooserDialogMethod "setStateFlags" o = WidgetSetStateFlagsMethodInfo
    ResolveFileChooserDialogMethod "setStyle" o = WidgetSetStyleMethodInfo
    ResolveFileChooserDialogMethod "setSupportMultidevice" o = WidgetSetSupportMultideviceMethodInfo
    ResolveFileChooserDialogMethod "setTitle" o = WindowSetTitleMethodInfo
    ResolveFileChooserDialogMethod "setTitlebar" o = WindowSetTitlebarMethodInfo
    ResolveFileChooserDialogMethod "setTooltipMarkup" o = WidgetSetTooltipMarkupMethodInfo
    ResolveFileChooserDialogMethod "setTooltipText" o = WidgetSetTooltipTextMethodInfo
    ResolveFileChooserDialogMethod "setTooltipWindow" o = WidgetSetTooltipWindowMethodInfo
    ResolveFileChooserDialogMethod "setTransientFor" o = WindowSetTransientForMethodInfo
    ResolveFileChooserDialogMethod "setTypeHint" o = WindowSetTypeHintMethodInfo
    ResolveFileChooserDialogMethod "setUrgencyHint" o = WindowSetUrgencyHintMethodInfo
    ResolveFileChooserDialogMethod "setUri" o = FileChooserSetUriMethodInfo
    ResolveFileChooserDialogMethod "setUsePreviewLabel" o = FileChooserSetUsePreviewLabelMethodInfo
    ResolveFileChooserDialogMethod "setValign" o = WidgetSetValignMethodInfo
    ResolveFileChooserDialogMethod "setVexpand" o = WidgetSetVexpandMethodInfo
    ResolveFileChooserDialogMethod "setVexpandSet" o = WidgetSetVexpandSetMethodInfo
    ResolveFileChooserDialogMethod "setVisible" o = WidgetSetVisibleMethodInfo
    ResolveFileChooserDialogMethod "setVisual" o = WidgetSetVisualMethodInfo
    ResolveFileChooserDialogMethod "setWindow" o = WidgetSetWindowMethodInfo
    ResolveFileChooserDialogMethod "setWmclass" o = WindowSetWmclassMethodInfo
    ResolveFileChooserDialogMethod l o = MethodResolutionFailed l o

instance (info ~ ResolveFileChooserDialogMethod t FileChooserDialog, MethodInfo info FileChooserDialog p) => IsLabelProxy t (FileChooserDialog -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolveFileChooserDialogMethod t FileChooserDialog, MethodInfo info FileChooserDialog p) => IsLabel t (FileChooserDialog -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif

type instance AttributeList FileChooserDialog = FileChooserDialogAttributeList
type FileChooserDialogAttributeList = ('[ '("acceptFocus", WindowAcceptFocusPropertyInfo), '("action", FileChooserActionPropertyInfo), '("appPaintable", WidgetAppPaintablePropertyInfo), '("application", WindowApplicationPropertyInfo), '("attachedTo", WindowAttachedToPropertyInfo), '("borderWidth", ContainerBorderWidthPropertyInfo), '("canDefault", WidgetCanDefaultPropertyInfo), '("canFocus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("compositeChild", WidgetCompositeChildPropertyInfo), '("createFolders", FileChooserCreateFoldersPropertyInfo), '("decorated", WindowDecoratedPropertyInfo), '("defaultHeight", WindowDefaultHeightPropertyInfo), '("defaultWidth", WindowDefaultWidthPropertyInfo), '("deletable", WindowDeletablePropertyInfo), '("destroyWithParent", WindowDestroyWithParentPropertyInfo), '("doOverwriteConfirmation", FileChooserDoOverwriteConfirmationPropertyInfo), '("doubleBuffered", WidgetDoubleBufferedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("extraWidget", FileChooserExtraWidgetPropertyInfo), '("filter", FileChooserFilterPropertyInfo), '("focusOnMap", WindowFocusOnMapPropertyInfo), '("focusVisible", WindowFocusVisiblePropertyInfo), '("gravity", WindowGravityPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("hasDefault", WidgetHasDefaultPropertyInfo), '("hasFocus", WidgetHasFocusPropertyInfo), '("hasResizeGrip", WindowHasResizeGripPropertyInfo), '("hasTooltip", WidgetHasTooltipPropertyInfo), '("hasToplevelFocus", WindowHasToplevelFocusPropertyInfo), '("heightRequest", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpandSet", WidgetHexpandSetPropertyInfo), '("hideTitlebarWhenMaximized", WindowHideTitlebarWhenMaximizedPropertyInfo), '("icon", WindowIconPropertyInfo), '("iconName", WindowIconNamePropertyInfo), '("isActive", WindowIsActivePropertyInfo), '("isFocus", WidgetIsFocusPropertyInfo), '("isMaximized", WindowIsMaximizedPropertyInfo), '("localOnly", FileChooserLocalOnlyPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("marginBottom", WidgetMarginBottomPropertyInfo), '("marginEnd", WidgetMarginEndPropertyInfo), '("marginLeft", WidgetMarginLeftPropertyInfo), '("marginRight", WidgetMarginRightPropertyInfo), '("marginStart", WidgetMarginStartPropertyInfo), '("marginTop", WidgetMarginTopPropertyInfo), '("mnemonicsVisible", WindowMnemonicsVisiblePropertyInfo), '("modal", WindowModalPropertyInfo), '("name", WidgetNamePropertyInfo), '("noShowAll", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("previewWidget", FileChooserPreviewWidgetPropertyInfo), '("previewWidgetActive", FileChooserPreviewWidgetActivePropertyInfo), '("receivesDefault", WidgetReceivesDefaultPropertyInfo), '("resizable", WindowResizablePropertyInfo), '("resizeGripVisible", WindowResizeGripVisiblePropertyInfo), '("resizeMode", ContainerResizeModePropertyInfo), '("role", WindowRolePropertyInfo), '("scaleFactor", WidgetScaleFactorPropertyInfo), '("screen", WindowScreenPropertyInfo), '("selectMultiple", FileChooserSelectMultiplePropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("showHidden", FileChooserShowHiddenPropertyInfo), '("skipPagerHint", WindowSkipPagerHintPropertyInfo), '("skipTaskbarHint", WindowSkipTaskbarHintPropertyInfo), '("startupId", WindowStartupIdPropertyInfo), '("style", WidgetStylePropertyInfo), '("title", WindowTitlePropertyInfo), '("tooltipMarkup", WidgetTooltipMarkupPropertyInfo), '("tooltipText", WidgetTooltipTextPropertyInfo), '("transientFor", WindowTransientForPropertyInfo), '("type", WindowTypePropertyInfo), '("typeHint", WindowTypeHintPropertyInfo), '("urgencyHint", WindowUrgencyHintPropertyInfo), '("useHeaderBar", DialogUseHeaderBarPropertyInfo), '("usePreviewLabel", FileChooserUsePreviewLabelPropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpandSet", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("widthRequest", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo), '("windowPosition", WindowWindowPositionPropertyInfo)] :: [(Symbol, *)])

type instance SignalList FileChooserDialog = FileChooserDialogSignalList
type FileChooserDialogSignalList = ('[ '("accelClosuresChanged", WidgetAccelClosuresChangedSignalInfo), '("activateDefault", WindowActivateDefaultSignalInfo), '("activateFocus", WindowActivateFocusSignalInfo), '("add", ContainerAddSignalInfo), '("buttonPressEvent", WidgetButtonPressEventSignalInfo), '("buttonReleaseEvent", WidgetButtonReleaseEventSignalInfo), '("canActivateAccel", WidgetCanActivateAccelSignalInfo), '("checkResize", ContainerCheckResizeSignalInfo), '("childNotify", WidgetChildNotifySignalInfo), '("close", DialogCloseSignalInfo), '("compositedChanged", WidgetCompositedChangedSignalInfo), '("configureEvent", WidgetConfigureEventSignalInfo), '("confirmOverwrite", FileChooserConfirmOverwriteSignalInfo), '("currentFolderChanged", FileChooserCurrentFolderChangedSignalInfo), '("damageEvent", WidgetDamageEventSignalInfo), '("deleteEvent", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroyEvent", WidgetDestroyEventSignalInfo), '("directionChanged", WidgetDirectionChangedSignalInfo), '("dragBegin", WidgetDragBeginSignalInfo), '("dragDataDelete", WidgetDragDataDeleteSignalInfo), '("dragDataGet", WidgetDragDataGetSignalInfo), '("dragDataReceived", WidgetDragDataReceivedSignalInfo), '("dragDrop", WidgetDragDropSignalInfo), '("dragEnd", WidgetDragEndSignalInfo), '("dragFailed", WidgetDragFailedSignalInfo), '("dragLeave", WidgetDragLeaveSignalInfo), '("dragMotion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("enableDebugging", WindowEnableDebuggingSignalInfo), '("enterNotifyEvent", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("eventAfter", WidgetEventAfterSignalInfo), '("fileActivated", FileChooserFileActivatedSignalInfo), '("focus", WidgetFocusSignalInfo), '("focusInEvent", WidgetFocusInEventSignalInfo), '("focusOutEvent", WidgetFocusOutEventSignalInfo), '("grabBrokenEvent", WidgetGrabBrokenEventSignalInfo), '("grabFocus", WidgetGrabFocusSignalInfo), '("grabNotify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchyChanged", WidgetHierarchyChangedSignalInfo), '("keyPressEvent", WidgetKeyPressEventSignalInfo), '("keyReleaseEvent", WidgetKeyReleaseEventSignalInfo), '("keynavFailed", WidgetKeynavFailedSignalInfo), '("keysChanged", WindowKeysChangedSignalInfo), '("leaveNotifyEvent", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("mapEvent", WidgetMapEventSignalInfo), '("mnemonicActivate", WidgetMnemonicActivateSignalInfo), '("motionNotifyEvent", WidgetMotionNotifyEventSignalInfo), '("moveFocus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parentSet", WidgetParentSetSignalInfo), '("popupMenu", WidgetPopupMenuSignalInfo), '("propertyNotifyEvent", WidgetPropertyNotifyEventSignalInfo), '("proximityInEvent", WidgetProximityInEventSignalInfo), '("proximityOutEvent", WidgetProximityOutEventSignalInfo), '("queryTooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("response", DialogResponseSignalInfo), '("screenChanged", WidgetScreenChangedSignalInfo), '("scrollEvent", WidgetScrollEventSignalInfo), '("selectionChanged", FileChooserSelectionChangedSignalInfo), '("selectionClearEvent", WidgetSelectionClearEventSignalInfo), '("selectionGet", WidgetSelectionGetSignalInfo), '("selectionNotifyEvent", WidgetSelectionNotifyEventSignalInfo), '("selectionReceived", WidgetSelectionReceivedSignalInfo), '("selectionRequestEvent", WidgetSelectionRequestEventSignalInfo), '("setFocus", WindowSetFocusSignalInfo), '("setFocusChild", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("showHelp", WidgetShowHelpSignalInfo), '("sizeAllocate", WidgetSizeAllocateSignalInfo), '("stateChanged", WidgetStateChangedSignalInfo), '("stateFlagsChanged", WidgetStateFlagsChangedSignalInfo), '("styleSet", WidgetStyleSetSignalInfo), '("styleUpdated", WidgetStyleUpdatedSignalInfo), '("touchEvent", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmapEvent", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("updatePreview", FileChooserUpdatePreviewSignalInfo), '("visibilityNotifyEvent", WidgetVisibilityNotifyEventSignalInfo), '("windowStateEvent", WidgetWindowStateEventSignalInfo)] :: [(Symbol, *)])


