

{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.Gtk.Objects.Plug
    ( 

-- * Exported types
    Plug(..)                                ,
    PlugK                                   ,
    toPlug                                  ,
    noPlug                                  ,


 -- * Methods
-- ** plugConstruct
    PlugConstructMethodInfo                 ,
    plugConstruct                           ,


-- ** plugConstructForDisplay
    PlugConstructForDisplayMethodInfo       ,
    plugConstructForDisplay                 ,


-- ** plugGetEmbedded
    PlugGetEmbeddedMethodInfo               ,
    plugGetEmbedded                         ,


-- ** plugGetId
    PlugGetIdMethodInfo                     ,
    plugGetId                               ,


-- ** plugGetSocketWindow
    PlugGetSocketWindowMethodInfo           ,
    plugGetSocketWindow                     ,


-- ** plugNew
    plugNew                                 ,


-- ** plugNewForDisplay
    plugNewForDisplay                       ,




 -- * Properties
-- ** Embedded
    PlugEmbeddedPropertyInfo                ,
    getPlugEmbedded                         ,
    plugEmbedded                            ,


-- ** SocketWindow
    PlugSocketWindowPropertyInfo            ,
    getPlugSocketWindow                     ,
    plugSocketWindow                        ,




 -- * Signals
-- ** Embedded
    PlugEmbeddedCallback                    ,
    PlugEmbeddedCallbackC                   ,
    PlugEmbeddedSignalInfo                  ,
    afterPlugEmbedded                       ,
    mkPlugEmbeddedCallback                  ,
    noPlugEmbeddedCallback                  ,
    onPlugEmbedded                          ,
    plugEmbeddedCallbackWrapper             ,
    plugEmbeddedClosure                     ,




    ) where

import Data.GI.Base.ShortPrelude

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.Gtk.Types
import GI.Gtk.Callbacks
import qualified GI.Atk as Atk
import qualified GI.GObject as GObject
import qualified GI.Gdk as Gdk

newtype Plug = Plug (ForeignPtr Plug)
foreign import ccall "gtk_plug_get_type"
    c_gtk_plug_get_type :: IO GType

type instance ParentTypes Plug = PlugParentTypes
type PlugParentTypes = '[Window, Bin, Container, Widget, GObject.Object, Atk.ImplementorIface, Buildable]

instance GObject Plug where
    gobjectIsInitiallyUnowned _ = True
    gobjectType _ = c_gtk_plug_get_type
    

class GObject o => PlugK o
instance (GObject o, IsDescendantOf Plug o) => PlugK o

toPlug :: PlugK o => o -> IO Plug
toPlug = unsafeCastTo Plug

noPlug :: Maybe Plug
noPlug = Nothing

type family ResolvePlugMethod (t :: Symbol) (o :: *) :: * where
    ResolvePlugMethod "activate" o = WidgetActivateMethodInfo
    ResolvePlugMethod "activateDefault" o = WindowActivateDefaultMethodInfo
    ResolvePlugMethod "activateFocus" o = WindowActivateFocusMethodInfo
    ResolvePlugMethod "activateKey" o = WindowActivateKeyMethodInfo
    ResolvePlugMethod "add" o = ContainerAddMethodInfo
    ResolvePlugMethod "addAccelGroup" o = WindowAddAccelGroupMethodInfo
    ResolvePlugMethod "addAccelerator" o = WidgetAddAcceleratorMethodInfo
    ResolvePlugMethod "addChild" o = BuildableAddChildMethodInfo
    ResolvePlugMethod "addDeviceEvents" o = WidgetAddDeviceEventsMethodInfo
    ResolvePlugMethod "addEvents" o = WidgetAddEventsMethodInfo
    ResolvePlugMethod "addMnemonic" o = WindowAddMnemonicMethodInfo
    ResolvePlugMethod "addMnemonicLabel" o = WidgetAddMnemonicLabelMethodInfo
    ResolvePlugMethod "addTickCallback" o = WidgetAddTickCallbackMethodInfo
    ResolvePlugMethod "beginMoveDrag" o = WindowBeginMoveDragMethodInfo
    ResolvePlugMethod "beginResizeDrag" o = WindowBeginResizeDragMethodInfo
    ResolvePlugMethod "bindProperty" o = GObject.ObjectBindPropertyMethodInfo
    ResolvePlugMethod "bindPropertyFull" o = GObject.ObjectBindPropertyFullMethodInfo
    ResolvePlugMethod "canActivateAccel" o = WidgetCanActivateAccelMethodInfo
    ResolvePlugMethod "checkResize" o = ContainerCheckResizeMethodInfo
    ResolvePlugMethod "childFocus" o = WidgetChildFocusMethodInfo
    ResolvePlugMethod "childGetProperty" o = ContainerChildGetPropertyMethodInfo
    ResolvePlugMethod "childNotifyByPspec" o = ContainerChildNotifyByPspecMethodInfo
    ResolvePlugMethod "childSetProperty" o = ContainerChildSetPropertyMethodInfo
    ResolvePlugMethod "childType" o = ContainerChildTypeMethodInfo
    ResolvePlugMethod "classPath" o = WidgetClassPathMethodInfo
    ResolvePlugMethod "close" o = WindowCloseMethodInfo
    ResolvePlugMethod "computeExpand" o = WidgetComputeExpandMethodInfo
    ResolvePlugMethod "construct" o = PlugConstructMethodInfo
    ResolvePlugMethod "constructChild" o = BuildableConstructChildMethodInfo
    ResolvePlugMethod "constructForDisplay" o = PlugConstructForDisplayMethodInfo
    ResolvePlugMethod "createPangoContext" o = WidgetCreatePangoContextMethodInfo
    ResolvePlugMethod "createPangoLayout" o = WidgetCreatePangoLayoutMethodInfo
    ResolvePlugMethod "customFinished" o = BuildableCustomFinishedMethodInfo
    ResolvePlugMethod "customTagEnd" o = BuildableCustomTagEndMethodInfo
    ResolvePlugMethod "customTagStart" o = BuildableCustomTagStartMethodInfo
    ResolvePlugMethod "deiconify" o = WindowDeiconifyMethodInfo
    ResolvePlugMethod "destroy" o = WidgetDestroyMethodInfo
    ResolvePlugMethod "destroyed" o = WidgetDestroyedMethodInfo
    ResolvePlugMethod "deviceIsShadowed" o = WidgetDeviceIsShadowedMethodInfo
    ResolvePlugMethod "dragBegin" o = WidgetDragBeginMethodInfo
    ResolvePlugMethod "dragBeginWithCoordinates" o = WidgetDragBeginWithCoordinatesMethodInfo
    ResolvePlugMethod "dragCheckThreshold" o = WidgetDragCheckThresholdMethodInfo
    ResolvePlugMethod "dragDestAddImageTargets" o = WidgetDragDestAddImageTargetsMethodInfo
    ResolvePlugMethod "dragDestAddTextTargets" o = WidgetDragDestAddTextTargetsMethodInfo
    ResolvePlugMethod "dragDestAddUriTargets" o = WidgetDragDestAddUriTargetsMethodInfo
    ResolvePlugMethod "dragDestFindTarget" o = WidgetDragDestFindTargetMethodInfo
    ResolvePlugMethod "dragDestGetTargetList" o = WidgetDragDestGetTargetListMethodInfo
    ResolvePlugMethod "dragDestGetTrackMotion" o = WidgetDragDestGetTrackMotionMethodInfo
    ResolvePlugMethod "dragDestSet" o = WidgetDragDestSetMethodInfo
    ResolvePlugMethod "dragDestSetProxy" o = WidgetDragDestSetProxyMethodInfo
    ResolvePlugMethod "dragDestSetTargetList" o = WidgetDragDestSetTargetListMethodInfo
    ResolvePlugMethod "dragDestSetTrackMotion" o = WidgetDragDestSetTrackMotionMethodInfo
    ResolvePlugMethod "dragDestUnset" o = WidgetDragDestUnsetMethodInfo
    ResolvePlugMethod "dragGetData" o = WidgetDragGetDataMethodInfo
    ResolvePlugMethod "dragHighlight" o = WidgetDragHighlightMethodInfo
    ResolvePlugMethod "dragSourceAddImageTargets" o = WidgetDragSourceAddImageTargetsMethodInfo
    ResolvePlugMethod "dragSourceAddTextTargets" o = WidgetDragSourceAddTextTargetsMethodInfo
    ResolvePlugMethod "dragSourceAddUriTargets" o = WidgetDragSourceAddUriTargetsMethodInfo
    ResolvePlugMethod "dragSourceGetTargetList" o = WidgetDragSourceGetTargetListMethodInfo
    ResolvePlugMethod "dragSourceSet" o = WidgetDragSourceSetMethodInfo
    ResolvePlugMethod "dragSourceSetIconGicon" o = WidgetDragSourceSetIconGiconMethodInfo
    ResolvePlugMethod "dragSourceSetIconName" o = WidgetDragSourceSetIconNameMethodInfo
    ResolvePlugMethod "dragSourceSetIconPixbuf" o = WidgetDragSourceSetIconPixbufMethodInfo
    ResolvePlugMethod "dragSourceSetIconStock" o = WidgetDragSourceSetIconStockMethodInfo
    ResolvePlugMethod "dragSourceSetTargetList" o = WidgetDragSourceSetTargetListMethodInfo
    ResolvePlugMethod "dragSourceUnset" o = WidgetDragSourceUnsetMethodInfo
    ResolvePlugMethod "dragUnhighlight" o = WidgetDragUnhighlightMethodInfo
    ResolvePlugMethod "draw" o = WidgetDrawMethodInfo
    ResolvePlugMethod "ensureStyle" o = WidgetEnsureStyleMethodInfo
    ResolvePlugMethod "errorBell" o = WidgetErrorBellMethodInfo
    ResolvePlugMethod "event" o = WidgetEventMethodInfo
    ResolvePlugMethod "forall" o = ContainerForallMethodInfo
    ResolvePlugMethod "forceFloating" o = GObject.ObjectForceFloatingMethodInfo
    ResolvePlugMethod "foreach" o = ContainerForeachMethodInfo
    ResolvePlugMethod "freezeChildNotify" o = WidgetFreezeChildNotifyMethodInfo
    ResolvePlugMethod "freezeNotify" o = GObject.ObjectFreezeNotifyMethodInfo
    ResolvePlugMethod "fullscreen" o = WindowFullscreenMethodInfo
    ResolvePlugMethod "fullscreenOnMonitor" o = WindowFullscreenOnMonitorMethodInfo
    ResolvePlugMethod "grabAdd" o = WidgetGrabAddMethodInfo
    ResolvePlugMethod "grabDefault" o = WidgetGrabDefaultMethodInfo
    ResolvePlugMethod "grabFocus" o = WidgetGrabFocusMethodInfo
    ResolvePlugMethod "grabRemove" o = WidgetGrabRemoveMethodInfo
    ResolvePlugMethod "hasDefault" o = WidgetHasDefaultMethodInfo
    ResolvePlugMethod "hasFocus" o = WidgetHasFocusMethodInfo
    ResolvePlugMethod "hasGrab" o = WidgetHasGrabMethodInfo
    ResolvePlugMethod "hasGroup" o = WindowHasGroupMethodInfo
    ResolvePlugMethod "hasRcStyle" o = WidgetHasRcStyleMethodInfo
    ResolvePlugMethod "hasScreen" o = WidgetHasScreenMethodInfo
    ResolvePlugMethod "hasToplevelFocus" o = WindowHasToplevelFocusMethodInfo
    ResolvePlugMethod "hasVisibleFocus" o = WidgetHasVisibleFocusMethodInfo
    ResolvePlugMethod "hide" o = WidgetHideMethodInfo
    ResolvePlugMethod "hideOnDelete" o = WidgetHideOnDeleteMethodInfo
    ResolvePlugMethod "iconify" o = WindowIconifyMethodInfo
    ResolvePlugMethod "inDestruction" o = WidgetInDestructionMethodInfo
    ResolvePlugMethod "initTemplate" o = WidgetInitTemplateMethodInfo
    ResolvePlugMethod "inputShapeCombineRegion" o = WidgetInputShapeCombineRegionMethodInfo
    ResolvePlugMethod "insertActionGroup" o = WidgetInsertActionGroupMethodInfo
    ResolvePlugMethod "intersect" o = WidgetIntersectMethodInfo
    ResolvePlugMethod "isActive" o = WindowIsActiveMethodInfo
    ResolvePlugMethod "isAncestor" o = WidgetIsAncestorMethodInfo
    ResolvePlugMethod "isComposited" o = WidgetIsCompositedMethodInfo
    ResolvePlugMethod "isDrawable" o = WidgetIsDrawableMethodInfo
    ResolvePlugMethod "isFloating" o = GObject.ObjectIsFloatingMethodInfo
    ResolvePlugMethod "isFocus" o = WidgetIsFocusMethodInfo
    ResolvePlugMethod "isMaximized" o = WindowIsMaximizedMethodInfo
    ResolvePlugMethod "isSensitive" o = WidgetIsSensitiveMethodInfo
    ResolvePlugMethod "isToplevel" o = WidgetIsToplevelMethodInfo
    ResolvePlugMethod "isVisible" o = WidgetIsVisibleMethodInfo
    ResolvePlugMethod "keynavFailed" o = WidgetKeynavFailedMethodInfo
    ResolvePlugMethod "listAccelClosures" o = WidgetListAccelClosuresMethodInfo
    ResolvePlugMethod "listActionPrefixes" o = WidgetListActionPrefixesMethodInfo
    ResolvePlugMethod "listMnemonicLabels" o = WidgetListMnemonicLabelsMethodInfo
    ResolvePlugMethod "map" o = WidgetMapMethodInfo
    ResolvePlugMethod "maximize" o = WindowMaximizeMethodInfo
    ResolvePlugMethod "modifyBase" o = WidgetModifyBaseMethodInfo
    ResolvePlugMethod "modifyBg" o = WidgetModifyBgMethodInfo
    ResolvePlugMethod "modifyCursor" o = WidgetModifyCursorMethodInfo
    ResolvePlugMethod "modifyFg" o = WidgetModifyFgMethodInfo
    ResolvePlugMethod "modifyFont" o = WidgetModifyFontMethodInfo
    ResolvePlugMethod "modifyStyle" o = WidgetModifyStyleMethodInfo
    ResolvePlugMethod "modifyText" o = WidgetModifyTextMethodInfo
    ResolvePlugMethod "move" o = WindowMoveMethodInfo
    ResolvePlugMethod "notify" o = GObject.ObjectNotifyMethodInfo
    ResolvePlugMethod "notifyByPspec" o = GObject.ObjectNotifyByPspecMethodInfo
    ResolvePlugMethod "overrideBackgroundColor" o = WidgetOverrideBackgroundColorMethodInfo
    ResolvePlugMethod "overrideColor" o = WidgetOverrideColorMethodInfo
    ResolvePlugMethod "overrideCursor" o = WidgetOverrideCursorMethodInfo
    ResolvePlugMethod "overrideFont" o = WidgetOverrideFontMethodInfo
    ResolvePlugMethod "overrideSymbolicColor" o = WidgetOverrideSymbolicColorMethodInfo
    ResolvePlugMethod "parseGeometry" o = WindowParseGeometryMethodInfo
    ResolvePlugMethod "parserFinished" o = BuildableParserFinishedMethodInfo
    ResolvePlugMethod "path" o = WidgetPathMethodInfo
    ResolvePlugMethod "present" o = WindowPresentMethodInfo
    ResolvePlugMethod "presentWithTime" o = WindowPresentWithTimeMethodInfo
    ResolvePlugMethod "propagateDraw" o = ContainerPropagateDrawMethodInfo
    ResolvePlugMethod "propagateKeyEvent" o = WindowPropagateKeyEventMethodInfo
    ResolvePlugMethod "queueComputeExpand" o = WidgetQueueComputeExpandMethodInfo
    ResolvePlugMethod "queueDraw" o = WidgetQueueDrawMethodInfo
    ResolvePlugMethod "queueDrawArea" o = WidgetQueueDrawAreaMethodInfo
    ResolvePlugMethod "queueDrawRegion" o = WidgetQueueDrawRegionMethodInfo
    ResolvePlugMethod "queueResize" o = WidgetQueueResizeMethodInfo
    ResolvePlugMethod "queueResizeNoRedraw" o = WidgetQueueResizeNoRedrawMethodInfo
    ResolvePlugMethod "realize" o = WidgetRealizeMethodInfo
    ResolvePlugMethod "ref" o = GObject.ObjectRefMethodInfo
    ResolvePlugMethod "refSink" o = GObject.ObjectRefSinkMethodInfo
    ResolvePlugMethod "regionIntersect" o = WidgetRegionIntersectMethodInfo
    ResolvePlugMethod "registerWindow" o = WidgetRegisterWindowMethodInfo
    ResolvePlugMethod "remove" o = ContainerRemoveMethodInfo
    ResolvePlugMethod "removeAccelGroup" o = WindowRemoveAccelGroupMethodInfo
    ResolvePlugMethod "removeAccelerator" o = WidgetRemoveAcceleratorMethodInfo
    ResolvePlugMethod "removeMnemonic" o = WindowRemoveMnemonicMethodInfo
    ResolvePlugMethod "removeMnemonicLabel" o = WidgetRemoveMnemonicLabelMethodInfo
    ResolvePlugMethod "removeTickCallback" o = WidgetRemoveTickCallbackMethodInfo
    ResolvePlugMethod "renderIcon" o = WidgetRenderIconMethodInfo
    ResolvePlugMethod "renderIconPixbuf" o = WidgetRenderIconPixbufMethodInfo
    ResolvePlugMethod "reparent" o = WidgetReparentMethodInfo
    ResolvePlugMethod "replaceData" o = GObject.ObjectReplaceDataMethodInfo
    ResolvePlugMethod "replaceQdata" o = GObject.ObjectReplaceQdataMethodInfo
    ResolvePlugMethod "resetRcStyles" o = WidgetResetRcStylesMethodInfo
    ResolvePlugMethod "resetStyle" o = WidgetResetStyleMethodInfo
    ResolvePlugMethod "reshowWithInitialSize" o = WindowReshowWithInitialSizeMethodInfo
    ResolvePlugMethod "resize" o = WindowResizeMethodInfo
    ResolvePlugMethod "resizeChildren" o = ContainerResizeChildrenMethodInfo
    ResolvePlugMethod "resizeGripIsVisible" o = WindowResizeGripIsVisibleMethodInfo
    ResolvePlugMethod "resizeToGeometry" o = WindowResizeToGeometryMethodInfo
    ResolvePlugMethod "runDispose" o = GObject.ObjectRunDisposeMethodInfo
    ResolvePlugMethod "sendExpose" o = WidgetSendExposeMethodInfo
    ResolvePlugMethod "sendFocusChange" o = WidgetSendFocusChangeMethodInfo
    ResolvePlugMethod "shapeCombineRegion" o = WidgetShapeCombineRegionMethodInfo
    ResolvePlugMethod "show" o = WidgetShowMethodInfo
    ResolvePlugMethod "showAll" o = WidgetShowAllMethodInfo
    ResolvePlugMethod "showNow" o = WidgetShowNowMethodInfo
    ResolvePlugMethod "sizeAllocate" o = WidgetSizeAllocateMethodInfo
    ResolvePlugMethod "sizeAllocateWithBaseline" o = WidgetSizeAllocateWithBaselineMethodInfo
    ResolvePlugMethod "sizeRequest" o = WidgetSizeRequestMethodInfo
    ResolvePlugMethod "stealData" o = GObject.ObjectStealDataMethodInfo
    ResolvePlugMethod "stealQdata" o = GObject.ObjectStealQdataMethodInfo
    ResolvePlugMethod "stick" o = WindowStickMethodInfo
    ResolvePlugMethod "styleAttach" o = WidgetStyleAttachMethodInfo
    ResolvePlugMethod "styleGetProperty" o = WidgetStyleGetPropertyMethodInfo
    ResolvePlugMethod "thawChildNotify" o = WidgetThawChildNotifyMethodInfo
    ResolvePlugMethod "thawNotify" o = GObject.ObjectThawNotifyMethodInfo
    ResolvePlugMethod "translateCoordinates" o = WidgetTranslateCoordinatesMethodInfo
    ResolvePlugMethod "triggerTooltipQuery" o = WidgetTriggerTooltipQueryMethodInfo
    ResolvePlugMethod "unfullscreen" o = WindowUnfullscreenMethodInfo
    ResolvePlugMethod "unmap" o = WidgetUnmapMethodInfo
    ResolvePlugMethod "unmaximize" o = WindowUnmaximizeMethodInfo
    ResolvePlugMethod "unparent" o = WidgetUnparentMethodInfo
    ResolvePlugMethod "unrealize" o = WidgetUnrealizeMethodInfo
    ResolvePlugMethod "unref" o = GObject.ObjectUnrefMethodInfo
    ResolvePlugMethod "unregisterWindow" o = WidgetUnregisterWindowMethodInfo
    ResolvePlugMethod "unsetFocusChain" o = ContainerUnsetFocusChainMethodInfo
    ResolvePlugMethod "unsetStateFlags" o = WidgetUnsetStateFlagsMethodInfo
    ResolvePlugMethod "unstick" o = WindowUnstickMethodInfo
    ResolvePlugMethod "watchClosure" o = GObject.ObjectWatchClosureMethodInfo
    ResolvePlugMethod "getAcceptFocus" o = WindowGetAcceptFocusMethodInfo
    ResolvePlugMethod "getAccessible" o = WidgetGetAccessibleMethodInfo
    ResolvePlugMethod "getActionGroup" o = WidgetGetActionGroupMethodInfo
    ResolvePlugMethod "getAllocatedBaseline" o = WidgetGetAllocatedBaselineMethodInfo
    ResolvePlugMethod "getAllocatedHeight" o = WidgetGetAllocatedHeightMethodInfo
    ResolvePlugMethod "getAllocatedWidth" o = WidgetGetAllocatedWidthMethodInfo
    ResolvePlugMethod "getAllocation" o = WidgetGetAllocationMethodInfo
    ResolvePlugMethod "getAncestor" o = WidgetGetAncestorMethodInfo
    ResolvePlugMethod "getAppPaintable" o = WidgetGetAppPaintableMethodInfo
    ResolvePlugMethod "getApplication" o = WindowGetApplicationMethodInfo
    ResolvePlugMethod "getAttachedTo" o = WindowGetAttachedToMethodInfo
    ResolvePlugMethod "getBorderWidth" o = ContainerGetBorderWidthMethodInfo
    ResolvePlugMethod "getCanDefault" o = WidgetGetCanDefaultMethodInfo
    ResolvePlugMethod "getCanFocus" o = WidgetGetCanFocusMethodInfo
    ResolvePlugMethod "getChild" o = BinGetChildMethodInfo
    ResolvePlugMethod "getChildRequisition" o = WidgetGetChildRequisitionMethodInfo
    ResolvePlugMethod "getChildVisible" o = WidgetGetChildVisibleMethodInfo
    ResolvePlugMethod "getChildren" o = ContainerGetChildrenMethodInfo
    ResolvePlugMethod "getClip" o = WidgetGetClipMethodInfo
    ResolvePlugMethod "getClipboard" o = WidgetGetClipboardMethodInfo
    ResolvePlugMethod "getCompositeName" o = WidgetGetCompositeNameMethodInfo
    ResolvePlugMethod "getData" o = GObject.ObjectGetDataMethodInfo
    ResolvePlugMethod "getDecorated" o = WindowGetDecoratedMethodInfo
    ResolvePlugMethod "getDefaultSize" o = WindowGetDefaultSizeMethodInfo
    ResolvePlugMethod "getDefaultWidget" o = WindowGetDefaultWidgetMethodInfo
    ResolvePlugMethod "getDeletable" o = WindowGetDeletableMethodInfo
    ResolvePlugMethod "getDestroyWithParent" o = WindowGetDestroyWithParentMethodInfo
    ResolvePlugMethod "getDeviceEnabled" o = WidgetGetDeviceEnabledMethodInfo
    ResolvePlugMethod "getDeviceEvents" o = WidgetGetDeviceEventsMethodInfo
    ResolvePlugMethod "getDirection" o = WidgetGetDirectionMethodInfo
    ResolvePlugMethod "getDisplay" o = WidgetGetDisplayMethodInfo
    ResolvePlugMethod "getDoubleBuffered" o = WidgetGetDoubleBufferedMethodInfo
    ResolvePlugMethod "getEmbedded" o = PlugGetEmbeddedMethodInfo
    ResolvePlugMethod "getEvents" o = WidgetGetEventsMethodInfo
    ResolvePlugMethod "getFocus" o = WindowGetFocusMethodInfo
    ResolvePlugMethod "getFocusChain" o = ContainerGetFocusChainMethodInfo
    ResolvePlugMethod "getFocusChild" o = ContainerGetFocusChildMethodInfo
    ResolvePlugMethod "getFocusHadjustment" o = ContainerGetFocusHadjustmentMethodInfo
    ResolvePlugMethod "getFocusOnMap" o = WindowGetFocusOnMapMethodInfo
    ResolvePlugMethod "getFocusVadjustment" o = ContainerGetFocusVadjustmentMethodInfo
    ResolvePlugMethod "getFocusVisible" o = WindowGetFocusVisibleMethodInfo
    ResolvePlugMethod "getFontMap" o = WidgetGetFontMapMethodInfo
    ResolvePlugMethod "getFontOptions" o = WidgetGetFontOptionsMethodInfo
    ResolvePlugMethod "getFrameClock" o = WidgetGetFrameClockMethodInfo
    ResolvePlugMethod "getGravity" o = WindowGetGravityMethodInfo
    ResolvePlugMethod "getGroup" o = WindowGetGroupMethodInfo
    ResolvePlugMethod "getHalign" o = WidgetGetHalignMethodInfo
    ResolvePlugMethod "getHasResizeGrip" o = WindowGetHasResizeGripMethodInfo
    ResolvePlugMethod "getHasTooltip" o = WidgetGetHasTooltipMethodInfo
    ResolvePlugMethod "getHasWindow" o = WidgetGetHasWindowMethodInfo
    ResolvePlugMethod "getHexpand" o = WidgetGetHexpandMethodInfo
    ResolvePlugMethod "getHexpandSet" o = WidgetGetHexpandSetMethodInfo
    ResolvePlugMethod "getHideTitlebarWhenMaximized" o = WindowGetHideTitlebarWhenMaximizedMethodInfo
    ResolvePlugMethod "getIcon" o = WindowGetIconMethodInfo
    ResolvePlugMethod "getIconList" o = WindowGetIconListMethodInfo
    ResolvePlugMethod "getIconName" o = WindowGetIconNameMethodInfo
    ResolvePlugMethod "getId" o = PlugGetIdMethodInfo
    ResolvePlugMethod "getInternalChild" o = BuildableGetInternalChildMethodInfo
    ResolvePlugMethod "getMapped" o = WidgetGetMappedMethodInfo
    ResolvePlugMethod "getMarginBottom" o = WidgetGetMarginBottomMethodInfo
    ResolvePlugMethod "getMarginEnd" o = WidgetGetMarginEndMethodInfo
    ResolvePlugMethod "getMarginLeft" o = WidgetGetMarginLeftMethodInfo
    ResolvePlugMethod "getMarginRight" o = WidgetGetMarginRightMethodInfo
    ResolvePlugMethod "getMarginStart" o = WidgetGetMarginStartMethodInfo
    ResolvePlugMethod "getMarginTop" o = WidgetGetMarginTopMethodInfo
    ResolvePlugMethod "getMnemonicModifier" o = WindowGetMnemonicModifierMethodInfo
    ResolvePlugMethod "getMnemonicsVisible" o = WindowGetMnemonicsVisibleMethodInfo
    ResolvePlugMethod "getModal" o = WindowGetModalMethodInfo
    ResolvePlugMethod "getModifierMask" o = WidgetGetModifierMaskMethodInfo
    ResolvePlugMethod "getModifierStyle" o = WidgetGetModifierStyleMethodInfo
    ResolvePlugMethod "getNoShowAll" o = WidgetGetNoShowAllMethodInfo
    ResolvePlugMethod "getPangoContext" o = WidgetGetPangoContextMethodInfo
    ResolvePlugMethod "getParent" o = WidgetGetParentMethodInfo
    ResolvePlugMethod "getParentWindow" o = WidgetGetParentWindowMethodInfo
    ResolvePlugMethod "getPath" o = WidgetGetPathMethodInfo
    ResolvePlugMethod "getPathForChild" o = ContainerGetPathForChildMethodInfo
    ResolvePlugMethod "getPointer" o = WidgetGetPointerMethodInfo
    ResolvePlugMethod "getPosition" o = WindowGetPositionMethodInfo
    ResolvePlugMethod "getPreferredHeight" o = WidgetGetPreferredHeightMethodInfo
    ResolvePlugMethod "getPreferredHeightAndBaselineForWidth" o = WidgetGetPreferredHeightAndBaselineForWidthMethodInfo
    ResolvePlugMethod "getPreferredHeightForWidth" o = WidgetGetPreferredHeightForWidthMethodInfo
    ResolvePlugMethod "getPreferredSize" o = WidgetGetPreferredSizeMethodInfo
    ResolvePlugMethod "getPreferredWidth" o = WidgetGetPreferredWidthMethodInfo
    ResolvePlugMethod "getPreferredWidthForHeight" o = WidgetGetPreferredWidthForHeightMethodInfo
    ResolvePlugMethod "getProperty" o = GObject.ObjectGetPropertyMethodInfo
    ResolvePlugMethod "getQdata" o = GObject.ObjectGetQdataMethodInfo
    ResolvePlugMethod "getRealized" o = WidgetGetRealizedMethodInfo
    ResolvePlugMethod "getReceivesDefault" o = WidgetGetReceivesDefaultMethodInfo
    ResolvePlugMethod "getRequestMode" o = WidgetGetRequestModeMethodInfo
    ResolvePlugMethod "getRequisition" o = WidgetGetRequisitionMethodInfo
    ResolvePlugMethod "getResizable" o = WindowGetResizableMethodInfo
    ResolvePlugMethod "getResizeGripArea" o = WindowGetResizeGripAreaMethodInfo
    ResolvePlugMethod "getResizeMode" o = ContainerGetResizeModeMethodInfo
    ResolvePlugMethod "getRole" o = WindowGetRoleMethodInfo
    ResolvePlugMethod "getRootWindow" o = WidgetGetRootWindowMethodInfo
    ResolvePlugMethod "getScaleFactor" o = WidgetGetScaleFactorMethodInfo
    ResolvePlugMethod "getSensitive" o = WidgetGetSensitiveMethodInfo
    ResolvePlugMethod "getSettings" o = WidgetGetSettingsMethodInfo
    ResolvePlugMethod "getSize" o = WindowGetSizeMethodInfo
    ResolvePlugMethod "getSizeRequest" o = WidgetGetSizeRequestMethodInfo
    ResolvePlugMethod "getSkipPagerHint" o = WindowGetSkipPagerHintMethodInfo
    ResolvePlugMethod "getSkipTaskbarHint" o = WindowGetSkipTaskbarHintMethodInfo
    ResolvePlugMethod "getSocketWindow" o = PlugGetSocketWindowMethodInfo
    ResolvePlugMethod "getState" o = WidgetGetStateMethodInfo
    ResolvePlugMethod "getStateFlags" o = WidgetGetStateFlagsMethodInfo
    ResolvePlugMethod "getStyle" o = WidgetGetStyleMethodInfo
    ResolvePlugMethod "getStyleContext" o = WidgetGetStyleContextMethodInfo
    ResolvePlugMethod "getSupportMultidevice" o = WidgetGetSupportMultideviceMethodInfo
    ResolvePlugMethod "getTemplateChild" o = WidgetGetTemplateChildMethodInfo
    ResolvePlugMethod "getTitle" o = WindowGetTitleMethodInfo
    ResolvePlugMethod "getTitlebar" o = WindowGetTitlebarMethodInfo
    ResolvePlugMethod "getTooltipMarkup" o = WidgetGetTooltipMarkupMethodInfo
    ResolvePlugMethod "getTooltipText" o = WidgetGetTooltipTextMethodInfo
    ResolvePlugMethod "getTooltipWindow" o = WidgetGetTooltipWindowMethodInfo
    ResolvePlugMethod "getToplevel" o = WidgetGetToplevelMethodInfo
    ResolvePlugMethod "getTransientFor" o = WindowGetTransientForMethodInfo
    ResolvePlugMethod "getTypeHint" o = WindowGetTypeHintMethodInfo
    ResolvePlugMethod "getUrgencyHint" o = WindowGetUrgencyHintMethodInfo
    ResolvePlugMethod "getValign" o = WidgetGetValignMethodInfo
    ResolvePlugMethod "getValignWithBaseline" o = WidgetGetValignWithBaselineMethodInfo
    ResolvePlugMethod "getVexpand" o = WidgetGetVexpandMethodInfo
    ResolvePlugMethod "getVexpandSet" o = WidgetGetVexpandSetMethodInfo
    ResolvePlugMethod "getVisible" o = WidgetGetVisibleMethodInfo
    ResolvePlugMethod "getVisual" o = WidgetGetVisualMethodInfo
    ResolvePlugMethod "getWindow" o = WidgetGetWindowMethodInfo
    ResolvePlugMethod "getWindowType" o = WindowGetWindowTypeMethodInfo
    ResolvePlugMethod "setAccelPath" o = WidgetSetAccelPathMethodInfo
    ResolvePlugMethod "setAcceptFocus" o = WindowSetAcceptFocusMethodInfo
    ResolvePlugMethod "setAllocation" o = WidgetSetAllocationMethodInfo
    ResolvePlugMethod "setAppPaintable" o = WidgetSetAppPaintableMethodInfo
    ResolvePlugMethod "setApplication" o = WindowSetApplicationMethodInfo
    ResolvePlugMethod "setAttachedTo" o = WindowSetAttachedToMethodInfo
    ResolvePlugMethod "setBorderWidth" o = ContainerSetBorderWidthMethodInfo
    ResolvePlugMethod "setBuildableProperty" o = BuildableSetBuildablePropertyMethodInfo
    ResolvePlugMethod "setCanDefault" o = WidgetSetCanDefaultMethodInfo
    ResolvePlugMethod "setCanFocus" o = WidgetSetCanFocusMethodInfo
    ResolvePlugMethod "setChildVisible" o = WidgetSetChildVisibleMethodInfo
    ResolvePlugMethod "setClip" o = WidgetSetClipMethodInfo
    ResolvePlugMethod "setCompositeName" o = WidgetSetCompositeNameMethodInfo
    ResolvePlugMethod "setData" o = GObject.ObjectSetDataMethodInfo
    ResolvePlugMethod "setDecorated" o = WindowSetDecoratedMethodInfo
    ResolvePlugMethod "setDefault" o = WindowSetDefaultMethodInfo
    ResolvePlugMethod "setDefaultGeometry" o = WindowSetDefaultGeometryMethodInfo
    ResolvePlugMethod "setDefaultSize" o = WindowSetDefaultSizeMethodInfo
    ResolvePlugMethod "setDeletable" o = WindowSetDeletableMethodInfo
    ResolvePlugMethod "setDestroyWithParent" o = WindowSetDestroyWithParentMethodInfo
    ResolvePlugMethod "setDeviceEnabled" o = WidgetSetDeviceEnabledMethodInfo
    ResolvePlugMethod "setDeviceEvents" o = WidgetSetDeviceEventsMethodInfo
    ResolvePlugMethod "setDirection" o = WidgetSetDirectionMethodInfo
    ResolvePlugMethod "setDoubleBuffered" o = WidgetSetDoubleBufferedMethodInfo
    ResolvePlugMethod "setEvents" o = WidgetSetEventsMethodInfo
    ResolvePlugMethod "setFocus" o = WindowSetFocusMethodInfo
    ResolvePlugMethod "setFocusChain" o = ContainerSetFocusChainMethodInfo
    ResolvePlugMethod "setFocusChild" o = ContainerSetFocusChildMethodInfo
    ResolvePlugMethod "setFocusHadjustment" o = ContainerSetFocusHadjustmentMethodInfo
    ResolvePlugMethod "setFocusOnMap" o = WindowSetFocusOnMapMethodInfo
    ResolvePlugMethod "setFocusVadjustment" o = ContainerSetFocusVadjustmentMethodInfo
    ResolvePlugMethod "setFocusVisible" o = WindowSetFocusVisibleMethodInfo
    ResolvePlugMethod "setFontMap" o = WidgetSetFontMapMethodInfo
    ResolvePlugMethod "setFontOptions" o = WidgetSetFontOptionsMethodInfo
    ResolvePlugMethod "setGeometryHints" o = WindowSetGeometryHintsMethodInfo
    ResolvePlugMethod "setGravity" o = WindowSetGravityMethodInfo
    ResolvePlugMethod "setHalign" o = WidgetSetHalignMethodInfo
    ResolvePlugMethod "setHasResizeGrip" o = WindowSetHasResizeGripMethodInfo
    ResolvePlugMethod "setHasTooltip" o = WidgetSetHasTooltipMethodInfo
    ResolvePlugMethod "setHasUserRefCount" o = WindowSetHasUserRefCountMethodInfo
    ResolvePlugMethod "setHasWindow" o = WidgetSetHasWindowMethodInfo
    ResolvePlugMethod "setHexpand" o = WidgetSetHexpandMethodInfo
    ResolvePlugMethod "setHexpandSet" o = WidgetSetHexpandSetMethodInfo
    ResolvePlugMethod "setHideTitlebarWhenMaximized" o = WindowSetHideTitlebarWhenMaximizedMethodInfo
    ResolvePlugMethod "setIcon" o = WindowSetIconMethodInfo
    ResolvePlugMethod "setIconFromFile" o = WindowSetIconFromFileMethodInfo
    ResolvePlugMethod "setIconList" o = WindowSetIconListMethodInfo
    ResolvePlugMethod "setIconName" o = WindowSetIconNameMethodInfo
    ResolvePlugMethod "setKeepAbove" o = WindowSetKeepAboveMethodInfo
    ResolvePlugMethod "setKeepBelow" o = WindowSetKeepBelowMethodInfo
    ResolvePlugMethod "setMapped" o = WidgetSetMappedMethodInfo
    ResolvePlugMethod "setMarginBottom" o = WidgetSetMarginBottomMethodInfo
    ResolvePlugMethod "setMarginEnd" o = WidgetSetMarginEndMethodInfo
    ResolvePlugMethod "setMarginLeft" o = WidgetSetMarginLeftMethodInfo
    ResolvePlugMethod "setMarginRight" o = WidgetSetMarginRightMethodInfo
    ResolvePlugMethod "setMarginStart" o = WidgetSetMarginStartMethodInfo
    ResolvePlugMethod "setMarginTop" o = WidgetSetMarginTopMethodInfo
    ResolvePlugMethod "setMnemonicModifier" o = WindowSetMnemonicModifierMethodInfo
    ResolvePlugMethod "setMnemonicsVisible" o = WindowSetMnemonicsVisibleMethodInfo
    ResolvePlugMethod "setModal" o = WindowSetModalMethodInfo
    ResolvePlugMethod "setNoShowAll" o = WidgetSetNoShowAllMethodInfo
    ResolvePlugMethod "setParent" o = WidgetSetParentMethodInfo
    ResolvePlugMethod "setParentWindow" o = WidgetSetParentWindowMethodInfo
    ResolvePlugMethod "setPosition" o = WindowSetPositionMethodInfo
    ResolvePlugMethod "setProperty" o = GObject.ObjectSetPropertyMethodInfo
    ResolvePlugMethod "setRealized" o = WidgetSetRealizedMethodInfo
    ResolvePlugMethod "setReallocateRedraws" o = ContainerSetReallocateRedrawsMethodInfo
    ResolvePlugMethod "setReceivesDefault" o = WidgetSetReceivesDefaultMethodInfo
    ResolvePlugMethod "setRedrawOnAllocate" o = WidgetSetRedrawOnAllocateMethodInfo
    ResolvePlugMethod "setResizable" o = WindowSetResizableMethodInfo
    ResolvePlugMethod "setResizeMode" o = ContainerSetResizeModeMethodInfo
    ResolvePlugMethod "setRole" o = WindowSetRoleMethodInfo
    ResolvePlugMethod "setScreen" o = WindowSetScreenMethodInfo
    ResolvePlugMethod "setSensitive" o = WidgetSetSensitiveMethodInfo
    ResolvePlugMethod "setSizeRequest" o = WidgetSetSizeRequestMethodInfo
    ResolvePlugMethod "setSkipPagerHint" o = WindowSetSkipPagerHintMethodInfo
    ResolvePlugMethod "setSkipTaskbarHint" o = WindowSetSkipTaskbarHintMethodInfo
    ResolvePlugMethod "setStartupId" o = WindowSetStartupIdMethodInfo
    ResolvePlugMethod "setState" o = WidgetSetStateMethodInfo
    ResolvePlugMethod "setStateFlags" o = WidgetSetStateFlagsMethodInfo
    ResolvePlugMethod "setStyle" o = WidgetSetStyleMethodInfo
    ResolvePlugMethod "setSupportMultidevice" o = WidgetSetSupportMultideviceMethodInfo
    ResolvePlugMethod "setTitle" o = WindowSetTitleMethodInfo
    ResolvePlugMethod "setTitlebar" o = WindowSetTitlebarMethodInfo
    ResolvePlugMethod "setTooltipMarkup" o = WidgetSetTooltipMarkupMethodInfo
    ResolvePlugMethod "setTooltipText" o = WidgetSetTooltipTextMethodInfo
    ResolvePlugMethod "setTooltipWindow" o = WidgetSetTooltipWindowMethodInfo
    ResolvePlugMethod "setTransientFor" o = WindowSetTransientForMethodInfo
    ResolvePlugMethod "setTypeHint" o = WindowSetTypeHintMethodInfo
    ResolvePlugMethod "setUrgencyHint" o = WindowSetUrgencyHintMethodInfo
    ResolvePlugMethod "setValign" o = WidgetSetValignMethodInfo
    ResolvePlugMethod "setVexpand" o = WidgetSetVexpandMethodInfo
    ResolvePlugMethod "setVexpandSet" o = WidgetSetVexpandSetMethodInfo
    ResolvePlugMethod "setVisible" o = WidgetSetVisibleMethodInfo
    ResolvePlugMethod "setVisual" o = WidgetSetVisualMethodInfo
    ResolvePlugMethod "setWindow" o = WidgetSetWindowMethodInfo
    ResolvePlugMethod "setWmclass" o = WindowSetWmclassMethodInfo
    ResolvePlugMethod l o = MethodResolutionFailed l o

instance (info ~ ResolvePlugMethod t Plug, MethodInfo info Plug p) => IsLabelProxy t (Plug -> p) where
    fromLabelProxy _ = overloadedMethod (MethodProxy :: MethodProxy info)

#if MIN_VERSION_base(4,9,0)
instance (info ~ ResolvePlugMethod t Plug, MethodInfo info Plug p) => IsLabel t (Plug -> p) where
    fromLabel _ = overloadedMethod (MethodProxy :: MethodProxy info)
#endif

-- signal Plug::embedded
type PlugEmbeddedCallback =
    IO ()

noPlugEmbeddedCallback :: Maybe PlugEmbeddedCallback
noPlugEmbeddedCallback = Nothing

type PlugEmbeddedCallbackC =
    Ptr () ->                               -- object
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkPlugEmbeddedCallback :: PlugEmbeddedCallbackC -> IO (FunPtr PlugEmbeddedCallbackC)

plugEmbeddedClosure :: PlugEmbeddedCallback -> IO Closure
plugEmbeddedClosure cb = newCClosure =<< mkPlugEmbeddedCallback wrapped
    where wrapped = plugEmbeddedCallbackWrapper cb

plugEmbeddedCallbackWrapper ::
    PlugEmbeddedCallback ->
    Ptr () ->
    Ptr () ->
    IO ()
plugEmbeddedCallbackWrapper _cb _ _ = do
    _cb 

onPlugEmbedded :: (GObject a, MonadIO m) => a -> PlugEmbeddedCallback -> m SignalHandlerId
onPlugEmbedded obj cb = liftIO $ connectPlugEmbedded obj cb SignalConnectBefore
afterPlugEmbedded :: (GObject a, MonadIO m) => a -> PlugEmbeddedCallback -> m SignalHandlerId
afterPlugEmbedded obj cb = connectPlugEmbedded obj cb SignalConnectAfter

connectPlugEmbedded :: (GObject a, MonadIO m) =>
                       a -> PlugEmbeddedCallback -> SignalConnectMode -> m SignalHandlerId
connectPlugEmbedded obj cb after = liftIO $ do
    cb' <- mkPlugEmbeddedCallback (plugEmbeddedCallbackWrapper cb)
    connectSignalFunPtr obj "embedded" cb' after

-- VVV Prop "embedded"
   -- Type: TBasicType TBoolean
   -- Flags: [PropertyReadable]
   -- Nullable: (Just False,Nothing)

getPlugEmbedded :: (MonadIO m, PlugK o) => o -> m Bool
getPlugEmbedded obj = liftIO $ getObjectPropertyBool obj "embedded"

data PlugEmbeddedPropertyInfo
instance AttrInfo PlugEmbeddedPropertyInfo where
    type AttrAllowedOps PlugEmbeddedPropertyInfo = '[ 'AttrGet]
    type AttrSetTypeConstraint PlugEmbeddedPropertyInfo = (~) ()
    type AttrBaseTypeConstraint PlugEmbeddedPropertyInfo = PlugK
    type AttrGetType PlugEmbeddedPropertyInfo = Bool
    type AttrLabel PlugEmbeddedPropertyInfo = "embedded"
    attrGet _ = getPlugEmbedded
    attrSet _ = undefined
    attrConstruct _ = undefined
    attrClear _ = undefined

-- VVV Prop "socket-window"
   -- Type: TInterface "Gdk" "Window"
   -- Flags: [PropertyReadable]
   -- Nullable: (Just False,Nothing)

getPlugSocketWindow :: (MonadIO m, PlugK o) => o -> m Gdk.Window
getPlugSocketWindow obj = liftIO $ checkUnexpectedNothing "getPlugSocketWindow" $ getObjectPropertyObject obj "socket-window" Gdk.Window

data PlugSocketWindowPropertyInfo
instance AttrInfo PlugSocketWindowPropertyInfo where
    type AttrAllowedOps PlugSocketWindowPropertyInfo = '[ 'AttrGet, 'AttrClear]
    type AttrSetTypeConstraint PlugSocketWindowPropertyInfo = (~) ()
    type AttrBaseTypeConstraint PlugSocketWindowPropertyInfo = PlugK
    type AttrGetType PlugSocketWindowPropertyInfo = Gdk.Window
    type AttrLabel PlugSocketWindowPropertyInfo = "socket-window"
    attrGet _ = getPlugSocketWindow
    attrSet _ = undefined
    attrConstruct _ = undefined
    attrClear _ = undefined

type instance AttributeList Plug = PlugAttributeList
type PlugAttributeList = ('[ '("acceptFocus", WindowAcceptFocusPropertyInfo), '("appPaintable", WidgetAppPaintablePropertyInfo), '("application", WindowApplicationPropertyInfo), '("attachedTo", WindowAttachedToPropertyInfo), '("borderWidth", ContainerBorderWidthPropertyInfo), '("canDefault", WidgetCanDefaultPropertyInfo), '("canFocus", WidgetCanFocusPropertyInfo), '("child", ContainerChildPropertyInfo), '("compositeChild", WidgetCompositeChildPropertyInfo), '("decorated", WindowDecoratedPropertyInfo), '("defaultHeight", WindowDefaultHeightPropertyInfo), '("defaultWidth", WindowDefaultWidthPropertyInfo), '("deletable", WindowDeletablePropertyInfo), '("destroyWithParent", WindowDestroyWithParentPropertyInfo), '("doubleBuffered", WidgetDoubleBufferedPropertyInfo), '("embedded", PlugEmbeddedPropertyInfo), '("events", WidgetEventsPropertyInfo), '("expand", WidgetExpandPropertyInfo), '("focusOnMap", WindowFocusOnMapPropertyInfo), '("focusVisible", WindowFocusVisiblePropertyInfo), '("gravity", WindowGravityPropertyInfo), '("halign", WidgetHalignPropertyInfo), '("hasDefault", WidgetHasDefaultPropertyInfo), '("hasFocus", WidgetHasFocusPropertyInfo), '("hasResizeGrip", WindowHasResizeGripPropertyInfo), '("hasTooltip", WidgetHasTooltipPropertyInfo), '("hasToplevelFocus", WindowHasToplevelFocusPropertyInfo), '("heightRequest", WidgetHeightRequestPropertyInfo), '("hexpand", WidgetHexpandPropertyInfo), '("hexpandSet", WidgetHexpandSetPropertyInfo), '("hideTitlebarWhenMaximized", WindowHideTitlebarWhenMaximizedPropertyInfo), '("icon", WindowIconPropertyInfo), '("iconName", WindowIconNamePropertyInfo), '("isActive", WindowIsActivePropertyInfo), '("isFocus", WidgetIsFocusPropertyInfo), '("isMaximized", WindowIsMaximizedPropertyInfo), '("margin", WidgetMarginPropertyInfo), '("marginBottom", WidgetMarginBottomPropertyInfo), '("marginEnd", WidgetMarginEndPropertyInfo), '("marginLeft", WidgetMarginLeftPropertyInfo), '("marginRight", WidgetMarginRightPropertyInfo), '("marginStart", WidgetMarginStartPropertyInfo), '("marginTop", WidgetMarginTopPropertyInfo), '("mnemonicsVisible", WindowMnemonicsVisiblePropertyInfo), '("modal", WindowModalPropertyInfo), '("name", WidgetNamePropertyInfo), '("noShowAll", WidgetNoShowAllPropertyInfo), '("opacity", WidgetOpacityPropertyInfo), '("parent", WidgetParentPropertyInfo), '("receivesDefault", WidgetReceivesDefaultPropertyInfo), '("resizable", WindowResizablePropertyInfo), '("resizeGripVisible", WindowResizeGripVisiblePropertyInfo), '("resizeMode", ContainerResizeModePropertyInfo), '("role", WindowRolePropertyInfo), '("scaleFactor", WidgetScaleFactorPropertyInfo), '("screen", WindowScreenPropertyInfo), '("sensitive", WidgetSensitivePropertyInfo), '("skipPagerHint", WindowSkipPagerHintPropertyInfo), '("skipTaskbarHint", WindowSkipTaskbarHintPropertyInfo), '("socketWindow", PlugSocketWindowPropertyInfo), '("startupId", WindowStartupIdPropertyInfo), '("style", WidgetStylePropertyInfo), '("title", WindowTitlePropertyInfo), '("tooltipMarkup", WidgetTooltipMarkupPropertyInfo), '("tooltipText", WidgetTooltipTextPropertyInfo), '("transientFor", WindowTransientForPropertyInfo), '("type", WindowTypePropertyInfo), '("typeHint", WindowTypeHintPropertyInfo), '("urgencyHint", WindowUrgencyHintPropertyInfo), '("valign", WidgetValignPropertyInfo), '("vexpand", WidgetVexpandPropertyInfo), '("vexpandSet", WidgetVexpandSetPropertyInfo), '("visible", WidgetVisiblePropertyInfo), '("widthRequest", WidgetWidthRequestPropertyInfo), '("window", WidgetWindowPropertyInfo), '("windowPosition", WindowWindowPositionPropertyInfo)] :: [(Symbol, *)])

plugEmbedded :: AttrLabelProxy "embedded"
plugEmbedded = AttrLabelProxy

plugSocketWindow :: AttrLabelProxy "socketWindow"
plugSocketWindow = AttrLabelProxy

data PlugEmbeddedSignalInfo
instance SignalInfo PlugEmbeddedSignalInfo where
    type HaskellCallbackType PlugEmbeddedSignalInfo = PlugEmbeddedCallback
    connectSignal _ = connectPlugEmbedded

type instance SignalList Plug = PlugSignalList
type PlugSignalList = ('[ '("accelClosuresChanged", WidgetAccelClosuresChangedSignalInfo), '("activateDefault", WindowActivateDefaultSignalInfo), '("activateFocus", WindowActivateFocusSignalInfo), '("add", ContainerAddSignalInfo), '("buttonPressEvent", WidgetButtonPressEventSignalInfo), '("buttonReleaseEvent", WidgetButtonReleaseEventSignalInfo), '("canActivateAccel", WidgetCanActivateAccelSignalInfo), '("checkResize", ContainerCheckResizeSignalInfo), '("childNotify", WidgetChildNotifySignalInfo), '("compositedChanged", WidgetCompositedChangedSignalInfo), '("configureEvent", WidgetConfigureEventSignalInfo), '("damageEvent", WidgetDamageEventSignalInfo), '("deleteEvent", WidgetDeleteEventSignalInfo), '("destroy", WidgetDestroySignalInfo), '("destroyEvent", WidgetDestroyEventSignalInfo), '("directionChanged", WidgetDirectionChangedSignalInfo), '("dragBegin", WidgetDragBeginSignalInfo), '("dragDataDelete", WidgetDragDataDeleteSignalInfo), '("dragDataGet", WidgetDragDataGetSignalInfo), '("dragDataReceived", WidgetDragDataReceivedSignalInfo), '("dragDrop", WidgetDragDropSignalInfo), '("dragEnd", WidgetDragEndSignalInfo), '("dragFailed", WidgetDragFailedSignalInfo), '("dragLeave", WidgetDragLeaveSignalInfo), '("dragMotion", WidgetDragMotionSignalInfo), '("draw", WidgetDrawSignalInfo), '("embedded", PlugEmbeddedSignalInfo), '("enableDebugging", WindowEnableDebuggingSignalInfo), '("enterNotifyEvent", WidgetEnterNotifyEventSignalInfo), '("event", WidgetEventSignalInfo), '("eventAfter", WidgetEventAfterSignalInfo), '("focus", WidgetFocusSignalInfo), '("focusInEvent", WidgetFocusInEventSignalInfo), '("focusOutEvent", WidgetFocusOutEventSignalInfo), '("grabBrokenEvent", WidgetGrabBrokenEventSignalInfo), '("grabFocus", WidgetGrabFocusSignalInfo), '("grabNotify", WidgetGrabNotifySignalInfo), '("hide", WidgetHideSignalInfo), '("hierarchyChanged", WidgetHierarchyChangedSignalInfo), '("keyPressEvent", WidgetKeyPressEventSignalInfo), '("keyReleaseEvent", WidgetKeyReleaseEventSignalInfo), '("keynavFailed", WidgetKeynavFailedSignalInfo), '("keysChanged", WindowKeysChangedSignalInfo), '("leaveNotifyEvent", WidgetLeaveNotifyEventSignalInfo), '("map", WidgetMapSignalInfo), '("mapEvent", WidgetMapEventSignalInfo), '("mnemonicActivate", WidgetMnemonicActivateSignalInfo), '("motionNotifyEvent", WidgetMotionNotifyEventSignalInfo), '("moveFocus", WidgetMoveFocusSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("parentSet", WidgetParentSetSignalInfo), '("popupMenu", WidgetPopupMenuSignalInfo), '("propertyNotifyEvent", WidgetPropertyNotifyEventSignalInfo), '("proximityInEvent", WidgetProximityInEventSignalInfo), '("proximityOutEvent", WidgetProximityOutEventSignalInfo), '("queryTooltip", WidgetQueryTooltipSignalInfo), '("realize", WidgetRealizeSignalInfo), '("remove", ContainerRemoveSignalInfo), '("screenChanged", WidgetScreenChangedSignalInfo), '("scrollEvent", WidgetScrollEventSignalInfo), '("selectionClearEvent", WidgetSelectionClearEventSignalInfo), '("selectionGet", WidgetSelectionGetSignalInfo), '("selectionNotifyEvent", WidgetSelectionNotifyEventSignalInfo), '("selectionReceived", WidgetSelectionReceivedSignalInfo), '("selectionRequestEvent", WidgetSelectionRequestEventSignalInfo), '("setFocus", WindowSetFocusSignalInfo), '("setFocusChild", ContainerSetFocusChildSignalInfo), '("show", WidgetShowSignalInfo), '("showHelp", WidgetShowHelpSignalInfo), '("sizeAllocate", WidgetSizeAllocateSignalInfo), '("stateChanged", WidgetStateChangedSignalInfo), '("stateFlagsChanged", WidgetStateFlagsChangedSignalInfo), '("styleSet", WidgetStyleSetSignalInfo), '("styleUpdated", WidgetStyleUpdatedSignalInfo), '("touchEvent", WidgetTouchEventSignalInfo), '("unmap", WidgetUnmapSignalInfo), '("unmapEvent", WidgetUnmapEventSignalInfo), '("unrealize", WidgetUnrealizeSignalInfo), '("visibilityNotifyEvent", WidgetVisibilityNotifyEventSignalInfo), '("windowStateEvent", WidgetWindowStateEventSignalInfo)] :: [(Symbol, *)])

-- method Plug::new
-- method type : Constructor
-- Args : [Arg {argCName = "socket_id", argType = TBasicType TULong, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface "Gtk" "Plug")
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_new" gtk_plug_new :: 
    CULong ->                               -- socket_id : TBasicType TULong
    IO (Ptr Plug)


plugNew ::
    (MonadIO m) =>
    CULong                                  -- socketId
    -> m Plug                               -- result
plugNew socketId = liftIO $ do
    result <- gtk_plug_new socketId
    checkUnexpectedReturnNULL "gtk_plug_new" result
    result' <- (newObject Plug) result
    return result'

-- method Plug::new_for_display
-- method type : Constructor
-- Args : [Arg {argCName = "display", argType = TInterface "Gdk" "Display", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "socket_id", argType = TBasicType TULong, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface "Gtk" "Plug")
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_new_for_display" gtk_plug_new_for_display :: 
    Ptr Gdk.Display ->                      -- display : TInterface "Gdk" "Display"
    CULong ->                               -- socket_id : TBasicType TULong
    IO (Ptr Plug)


plugNewForDisplay ::
    (MonadIO m, Gdk.DisplayK a) =>
    a                                       -- display
    -> CULong                               -- socketId
    -> m Plug                               -- result
plugNewForDisplay display socketId = liftIO $ do
    let display' = unsafeManagedPtrCastPtr display
    result <- gtk_plug_new_for_display display' socketId
    checkUnexpectedReturnNULL "gtk_plug_new_for_display" result
    result' <- (newObject Plug) result
    touchManagedPtr display
    return result'

-- method Plug::construct
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Plug", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "socket_id", argType = TBasicType TULong, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_construct" gtk_plug_construct :: 
    Ptr Plug ->                             -- _obj : TInterface "Gtk" "Plug"
    CULong ->                               -- socket_id : TBasicType TULong
    IO ()


plugConstruct ::
    (MonadIO m, PlugK a) =>
    a                                       -- _obj
    -> CULong                               -- socketId
    -> m ()                                 -- result
plugConstruct _obj socketId = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    gtk_plug_construct _obj' socketId
    touchManagedPtr _obj
    return ()

data PlugConstructMethodInfo
instance (signature ~ (CULong -> m ()), MonadIO m, PlugK a) => MethodInfo PlugConstructMethodInfo a signature where
    overloadedMethod _ = plugConstruct

-- method Plug::construct_for_display
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Plug", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "display", argType = TInterface "Gdk" "Display", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing},Arg {argCName = "socket_id", argType = TBasicType TULong, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_construct_for_display" gtk_plug_construct_for_display :: 
    Ptr Plug ->                             -- _obj : TInterface "Gtk" "Plug"
    Ptr Gdk.Display ->                      -- display : TInterface "Gdk" "Display"
    CULong ->                               -- socket_id : TBasicType TULong
    IO ()


plugConstructForDisplay ::
    (MonadIO m, PlugK a, Gdk.DisplayK b) =>
    a                                       -- _obj
    -> b                                    -- display
    -> CULong                               -- socketId
    -> m ()                                 -- result
plugConstructForDisplay _obj display socketId = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let display' = unsafeManagedPtrCastPtr display
    gtk_plug_construct_for_display _obj' display' socketId
    touchManagedPtr _obj
    touchManagedPtr display
    return ()

data PlugConstructForDisplayMethodInfo
instance (signature ~ (b -> CULong -> m ()), MonadIO m, PlugK a, Gdk.DisplayK b) => MethodInfo PlugConstructForDisplayMethodInfo a signature where
    overloadedMethod _ = plugConstructForDisplay

-- method Plug::get_embedded
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Plug", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TBoolean)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_get_embedded" gtk_plug_get_embedded :: 
    Ptr Plug ->                             -- _obj : TInterface "Gtk" "Plug"
    IO CInt


plugGetEmbedded ::
    (MonadIO m, PlugK a) =>
    a                                       -- _obj
    -> m Bool                               -- result
plugGetEmbedded _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_plug_get_embedded _obj'
    let result' = (/= 0) result
    touchManagedPtr _obj
    return result'

data PlugGetEmbeddedMethodInfo
instance (signature ~ (m Bool), MonadIO m, PlugK a) => MethodInfo PlugGetEmbeddedMethodInfo a signature where
    overloadedMethod _ = plugGetEmbedded

-- method Plug::get_id
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Plug", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TBasicType TULong)
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_get_id" gtk_plug_get_id :: 
    Ptr Plug ->                             -- _obj : TInterface "Gtk" "Plug"
    IO CULong


plugGetId ::
    (MonadIO m, PlugK a) =>
    a                                       -- _obj
    -> m CULong                             -- result
plugGetId _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_plug_get_id _obj'
    touchManagedPtr _obj
    return result

data PlugGetIdMethodInfo
instance (signature ~ (m CULong), MonadIO m, PlugK a) => MethodInfo PlugGetIdMethodInfo a signature where
    overloadedMethod _ = plugGetId

-- method Plug::get_socket_window
-- method type : OrdinaryMethod
-- Args : [Arg {argCName = "_obj", argType = TInterface "Gtk" "Plug", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, argCallerAllocates = False, transfer = TransferNothing}]
-- Lengths : []
-- returnType : Just (TInterface "Gdk" "Window")
-- throws : False
-- Skip return : False

foreign import ccall "gtk_plug_get_socket_window" gtk_plug_get_socket_window :: 
    Ptr Plug ->                             -- _obj : TInterface "Gtk" "Plug"
    IO (Ptr Gdk.Window)


plugGetSocketWindow ::
    (MonadIO m, PlugK a) =>
    a                                       -- _obj
    -> m Gdk.Window                         -- result
plugGetSocketWindow _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- gtk_plug_get_socket_window _obj'
    checkUnexpectedReturnNULL "gtk_plug_get_socket_window" result
    result' <- (newObject Gdk.Window) result
    touchManagedPtr _obj
    return result'

data PlugGetSocketWindowMethodInfo
instance (signature ~ (m Gdk.Window), MonadIO m, PlugK a) => MethodInfo PlugGetSocketWindowMethodInfo a signature where
    overloadedMethod _ = plugGetSocketWindow


